@@ -1,4 +1,4 @@
-/******************************************************************************
+ /******************************************************************************
 The MIT License(MIT)
 
 Embedded Template Library.
@@ -221,7 +221,7 @@ namespace etl
         if (timer.id != etl::timer::id::NO_TIMER)
         {
           // Has a valid period.
-          if (timer.period != etl::timer::state::INACTIVE)
+          if (timer.period != etl::timer::state::Inactive)
           {
             TInterruptGuard guard;
             (void)guard; // Silence 'unused variable warnings.
@@ -300,6 +300,62 @@ namespace etl
       return false;
     }
 
+    //*******************************************
+    /// Check if there is an active timer.
+    //*******************************************
+    bool has_active_timer() const
+    {
+      TInterruptGuard guard;
+      (void)guard; // Silence 'unused variable warnings.
+      return !active_list.empty();
+    }
+
+    //*******************************************
+    /// Get the time to the next timer event.
+    /// Returns etl::timer::interval::No_Active_Interval if there is no active timer.
+    //*******************************************
+    uint32_t time_to_next() const
+    {
+      uint32_t delta = static_cast<uint32_t>(etl::timer::interval::No_Active_Interval);
+
+      TInterruptGuard guard;
+      (void)guard; // Silence 'unused variable warnings.
+
+      if (!active_list.empty())
+      {
+        delta = active_list.front().delta;
+      }
+
+      return delta;
+    }
+
+    //*******************************************
+    /// Checks if a timer is currently active.
+    /// Returns <b>true</b> if the timer is active, otherwise <b>false</b>.
+    //*******************************************
+    bool is_active(etl::timer::id::type id_) const
+    {
+      // Valid timer id?
+      if (is_valid_timer_id(id_))
+      {
+        if (has_active_timer())
+        {
+          TInterruptGuard guard;
+          (void)guard;  // Silence 'unused variable warnings.
+
+          const timer_data& timer = timer_array[id_];
+
+          // Registered timer?
+          if (timer.id != etl::timer::id::NO_TIMER)
+          {
+            return timer.is_active();
+          }
+        }
+      }
+
+      return false;
+    }
+
   protected:
 
     //*************************************************************************
@@ -310,7 +366,7 @@ namespace etl
       timer_data()
         : callback()
         , period(0U)
-        , delta(etl::timer::state::INACTIVE)
+        , delta(etl::timer::state::Inactive)
         , id(etl::timer::id::NO_TIMER)
         , previous(etl::timer::id::NO_TIMER)
         , next(etl::timer::id::NO_TIMER)
@@ -327,7 +383,7 @@ namespace etl
                  bool                 repeating_)
         : callback(callback_)
         , period(period_)
-        , delta(etl::timer::state::INACTIVE)
+        , delta(etl::timer::state::Inactive)
         , id(id_)
         , previous(etl::timer::id::NO_TIMER)
         , next(etl::timer::id::NO_TIMER)
@@ -340,7 +396,7 @@ namespace etl
       //*******************************************
       bool is_active() const
       {
-        return delta != etl::timer::state::INACTIVE;
+        return delta != etl::timer::state::Inactive;
       }
 
       //*******************************************
@@ -348,7 +404,7 @@ namespace etl
       //*******************************************
       void set_inactive()
       {
-        delta = etl::timer::state::INACTIVE;
+        delta = etl::timer::state::Inactive;
       }
 
       callback_type        callback;
@@ -370,16 +426,24 @@ namespace etl
     /// Constructor.
     //*******************************************
     icallback_timer_interrupt(timer_data* const timer_array_, const uint_least8_t  MAX_TIMERS_)
-      : timer_array(timer_array_),
-        active_list(timer_array_),
-        enabled(false),
-        number_of_registered_timers(0U),
-        MAX_TIMERS(MAX_TIMERS_)
+      : timer_array(timer_array_)
+      , active_list(timer_array_)
+      , enabled(false)
+      , number_of_registered_timers(0U)
+      , MAX_TIMERS(MAX_TIMERS_)
     {
     }
 
   private:
 
+    //*******************************************
+    /// Check that the timer id is valid.
+    //*******************************************
+    bool is_valid_timer_id(etl::timer::id::type id_) const
+    {
+      return (id_ < MAX_TIMERS);
+    }
+
     //*************************************************************************
     /// A specialised intrusive linked list for timer data.
     //*************************************************************************
@@ -501,8 +565,8 @@ namespace etl
         }
 
         timer.previous = etl::timer::id::NO_TIMER;
-        timer.next = etl::timer::id::NO_TIMER;
-        timer.delta = etl::timer::state::INACTIVE;
+        timer.next     = etl::timer::id::NO_TIMER;
+        timer.delta    = etl::timer::state::Inactive;
       }
 
       //*******************************
@@ -511,6 +575,12 @@ namespace etl
         return ptimers[head];
       }
 
+      //*******************************
+      const timer_data& front() const
+      {
+        return ptimers[head];
+      }
+
       //*******************************
       etl::timer::id::type begin()
       {
@@ -544,8 +614,8 @@ namespace etl
           timer.next = etl::timer::id::NO_TIMER;
         }
 
-        head = etl::timer::id::NO_TIMER;
-        tail = etl::timer::id::NO_TIMER;
+        head    = etl::timer::id::NO_TIMER;
+        tail    = etl::timer::id::NO_TIMER;
         current = etl::timer::id::NO_TIMER;
       }
 
