@@ -103,5 +103,6 @@ SOFTWARE.
 #define ETL_EXPECTED_FILE_ID "70"
 #define ETL_ALIGNMENT_FILE_ID "71"
 #define ETL_BASE64_FILE_ID "72"
-
+#define ETL_SINGLETON_BASE_FILE_ID "73"
+#define ETL_UNALIGNED_TYPE_FILE_ID "74"
 #endif
