@@ -177,20 +177,16 @@ namespace etl
 
       link_type* p_last = &start;
 
-      int count = 0;
-
       // Add all of the elements.
       while (first != last)
       {
-        ++count;
-
-        link_type& value = *first++;
+         link_type& value = *first++;
 
         ETL_ASSERT_OR_RETURN(!value.is_linked(), ETL_ERROR(intrusive_forward_list_value_is_already_linked));
 
-        value.etl_next = p_last->etl_next;
+        value.etl_next   = p_last->etl_next;
         p_last->etl_next = &value;
-        p_last = &value;
+        p_last           = &value;
         ++current_size;
       }
     }
@@ -213,7 +209,7 @@ namespace etl
 #if defined(ETL_CHECK_PUSH_POP)
       ETL_ASSERT_OR_RETURN(!empty(), ETL_ERROR(intrusive_forward_list_empty));
 #endif
-      remove_link_after(start);
+      disconnect_link_after(start);
     }
 
     //*************************************************************************
@@ -232,7 +228,7 @@ namespace etl
         
       while (next != &terminator)
       {
-        next = next->etl_next;    // Point to next link.
+        next     = next->etl_next;    // Point to next link.
         current->etl_next = previous; // Reverse the current link.
         previous = current;           // Previous points to current.
         current  = next;              // Current points to next.
@@ -301,7 +297,7 @@ namespace etl
     //*************************************************************************
     /// Remove a link.
     //*************************************************************************
-    void remove_link_after(link_type& link)
+    void disconnect_link_after(link_type& link)
     {
       link_type* p_next = link.etl_next;
 
@@ -337,6 +333,89 @@ namespace etl
       start.etl_next = &terminator;
       current_size = 0;
     }
+
+    //*************************************************************************
+    /// Tests if the link is in this list.
+    /// Returns the previous link to it, if found, otherwise ETL_NULLPTR.
+    //*************************************************************************
+    link_type* is_link_in_list(link_type& search_link)
+    {
+      link_type* p_link     = start.etl_next;
+      link_type* p_previous = &start;
+
+      while (p_link != ETL_NULLPTR)
+      {
+        if (&search_link == p_link)
+        {
+          return p_previous;
+        }
+
+        p_previous = p_link;
+
+        if (p_link != ETL_NULLPTR)
+        {
+          p_link = p_link->link_type::etl_next;
+        }
+      }
+
+      return ETL_NULLPTR;
+    }
+
+    //*************************************************************************
+    /// Remove the specified node from the list.
+    /// Returns ETL_NULLPTR if the link was not in this list.
+    /// Returns the next 
+    //*************************************************************************
+    link_type* remove_link(link_type& link)
+    {
+      link_type* result = ETL_NULLPTR;
+
+      link_type* p_previous = is_link_in_list(link);
+
+      if (p_previous != ETL_NULLPTR)
+      {
+        link_type* p_next = link.etl_next;
+
+        disconnect_link_after(*p_previous);
+
+        if (p_next != &this->terminator)
+        {
+          result = p_next;
+        }
+      }
+
+      return result;
+    }
+
+    //*************************************************************************
+    /// Remove a range of elements.
+    //*************************************************************************
+    link_type* remove_link_range_after(link_type* p_first, link_type* p_last)
+    {
+      link_type* p_after = p_first->etl_next;
+
+      // Join the ends.
+      etl::link<link_type>(p_first, p_last);
+
+      // Unlink the erased range.
+      link_type* p_unlink = p_after;
+
+      while (p_unlink != p_last)
+      {
+        link_type* p_next = p_unlink->etl_next;
+        p_unlink->clear();
+        p_unlink = p_next;
+      }
+
+      if (p_after == &this->terminator)
+      {
+        return ETL_NULLPTR;
+      }
+      else
+      {
+        return p_last;
+      }
+    }
   };
 
   template <typename TLink>
@@ -365,6 +444,8 @@ namespace etl
 
     typedef intrusive_forward_list<TValue, TLink> list_type;
 
+    typedef TValue node_type;
+
     //*************************************************************************
     /// iterator.
     //*************************************************************************
@@ -408,7 +489,9 @@ namespace etl
 
       reference operator *() const
       {
+#include "private/diagnostic_null_dereference_push.h"
         return *static_cast<pointer>(p_value);
+#include "private/diagnostic_pop.h"
       }
 
       pointer operator &() const
@@ -666,7 +749,7 @@ namespace etl
         if (next != end())
         {
           ++next;
-          this->remove_link_after(*position.p_value);
+          this->disconnect_link_after(*position.p_value);
         }
       }
 
@@ -684,22 +767,9 @@ namespace etl
 
         link_type* p_first = first.p_value;
         link_type* p_last  = last.p_value;
-        link_type* p_after = p_first->etl_next;
-        
-        // Join the ends.
-        etl::link<link_type>(p_first, p_last);
+        link_type* p_after = this->remove_link_range_after(p_first, p_last);
 
-        // Unlink the erased range.
-        link_type* p_unlink = p_after;
-
-        while (p_unlink != p_last)
-        {
-          link_type* p_next = p_unlink->etl_next;
-          p_unlink->clear();
-          p_unlink = p_next;
-        }
-
-        if (p_after == &this->terminator)
+        if (p_after == ETL_NULLPTR)
         {
           return end();
         }
@@ -714,6 +784,14 @@ namespace etl
       }
     }
 
+    //*************************************************************************
+    /// Erases the specified node.
+    //*************************************************************************
+    node_type* erase(node_type& node)
+    {
+      return static_cast<node_type*>(this->remove_link(node));
+    }
+
     //*************************************************************************
     /// Removes all but the one element from every consecutive group of equal
     /// elements in the container.
@@ -734,7 +812,7 @@ namespace etl
         // Is this value the same as the last?
         if (isEqual(*static_cast<pointer>(current), *static_cast<pointer>(last)))
         {
-          this->remove_link_after(*last);
+          this->disconnect_link_after(*last);
         }
         else
         {
