@@ -54,6 +54,27 @@ SOFTWARE.
 
 namespace etl
 {
+  //*****************************************************************************
+  /// Obtain the address represented by p without forming a reference to the object pointed to by p.
+  /// Defined when not using the STL or C++20
+  //*****************************************************************************
+  template <typename T>
+  ETL_CONSTEXPR T* to_address(T* p) 
+  { 
+    return p; 
+  }
+
+  //*****************************************************************************
+  /// Obtain the address represented by itr without forming a reference to the object pointed to by itr.
+  /// Requires that the iterator defines operator->()
+  /// Defined when not using the STL or C++20
+  //*****************************************************************************
+  template <typename Iterator>
+  ETL_CONSTEXPR typename Iterator::pointer to_address(const Iterator& itr)
+  {
+    return etl::to_address(itr.operator->());
+  }
+
 #if ETL_USING_STL
   //*****************************************************************************
   /// Fills uninitialised memory range with a value.
@@ -112,7 +133,7 @@ namespace etl
 
     while (o_begin != o_end)
     {
-      ::new (static_cast<void*>(etl::addressof(*o_begin))) value_type(value);
+      ::new (static_cast<void*>(etl::to_address(o_begin))) value_type(value);
       ++o_begin;
     }
 
@@ -259,7 +280,7 @@ namespace etl
 
     while (i_begin != i_end)
     {
-      ::new (static_cast<void*>(etl::addressof(*o_end))) value_type(*i_begin);
+      ::new (static_cast<void*>(etl::to_address(o_end))) value_type(*i_begin);
       ++i_begin;
       ++o_end;
     }
@@ -407,7 +428,7 @@ namespace etl
 
     while (i_begin != i_end)
     {
-      ::new (static_cast<void*>(etl::addressof(*o_end))) value_type(etl::move(*i_begin));
+      ::new (static_cast<void*>(etl::to_address(o_end))) value_type(etl::move(*i_begin));
       ++i_begin;
       ++o_end;
     }
@@ -532,7 +553,7 @@ namespace etl
 
     while (n-- != 0)
     {
-      ::new (static_cast<void*>(etl::addressof(*o_end))) value_type(etl::move(*i_begin));
+      ::new (static_cast<void*>(etl::to_address(o_end))) value_type(etl::move(*i_begin));
       ++i_begin;
       ++o_end;
     }
@@ -665,7 +686,7 @@ namespace etl
 
     while (o_begin != o_end)
     {
-      ::new (static_cast<void*>(etl::addressof(*o_begin))) value_type;
+      ::new (static_cast<void*>(etl::to_address(o_begin))) value_type;
       ++o_begin;
     }
   }
@@ -844,7 +865,7 @@ namespace etl
 
     while (o_begin != o_end)
     {
-      ::new (static_cast<void*>(etl::addressof(*o_begin))) value_type();
+      ::new (static_cast<void*>(etl::to_address(o_begin))) value_type();
       ++o_begin;
     }
   }
@@ -1095,7 +1116,7 @@ namespace etl
   {
     while (i_begin != i_end)
     {
-      etl::destroy_at(etl::addressof(*i_begin));
+      etl::destroy_at(etl::to_address(i_begin));
       ++i_begin;
     }
   }
@@ -1127,7 +1148,7 @@ namespace etl
 
     while (i_begin != i_end)
     {
-      etl::destroy_at(etl::addressof(*i_begin));
+      etl::destroy_at(etl::to_address(i_begin));
       ++i_begin;
     }
   }
@@ -1182,7 +1203,7 @@ namespace etl
   {
     while (n > 0)
     {
-      etl::destroy_at(etl::addressof(*i_begin));
+      etl::destroy_at(etl::to_address(i_begin));
       ++i_begin;
       --n;
     }
@@ -1218,7 +1239,7 @@ namespace etl
 
     while (n > 0)
     {
-      etl::destroy_at(etl::addressof(*i_begin));
+      etl::destroy_at(etl::to_address(i_begin));
       ++i_begin;
       --n;
     }
@@ -2264,13 +2285,13 @@ namespace etl
   /// \param destination begin
   /// \return A pointer to the destination.
   //***************************************************************************
-  template <typename TPointer>
-  typename etl::enable_if<etl::is_trivially_copyable<typename etl::iterator_traits<TPointer>::value_type>::value, TPointer>::type
-    mem_copy(const TPointer sb, const TPointer se, TPointer db) ETL_NOEXCEPT
+  template <typename T>
+  typename etl::enable_if<etl::is_trivially_copyable<typename etl::iterator_traits<T*>::value_type>::value, T*>::type
+    mem_copy(const T* sb, const T* se, T* db) ETL_NOEXCEPT
   {
-    return reinterpret_cast<TPointer>(memcpy(reinterpret_cast<void*>(db), 
-                                             reinterpret_cast<void*>(sb), 
-                                             sizeof(typename etl::iterator_traits<TPointer>::value_type) * static_cast<size_t>(se - sb)));
+    return reinterpret_cast<T*>(memcpy(reinterpret_cast<void*>(db),
+                                       reinterpret_cast<const void*>(sb),
+                                       sizeof(typename etl::iterator_traits<T*>::value_type) * static_cast<size_t>(se - sb)));
   }
 
   //***************************************************************************
@@ -2280,13 +2301,13 @@ namespace etl
   /// \param source length
   /// \param destination begin
   //***************************************************************************
-  template <typename TPointer>
-  typename etl::enable_if<etl::is_trivially_copyable<typename etl::iterator_traits<TPointer>::value_type>::value, TPointer>::type
-    mem_copy(const TPointer sb, size_t n, TPointer db) ETL_NOEXCEPT
+  template <typename T>
+  typename etl::enable_if<etl::is_trivially_copyable<typename etl::iterator_traits<T*>::value_type>::value, T*>::type
+    mem_copy(const T* sb, size_t n, T* db) ETL_NOEXCEPT
   {
-    return reinterpret_cast<TPointer>(memcpy(reinterpret_cast<void*>(db), 
-                                             reinterpret_cast<void*>(sb), 
-                                             sizeof(typename etl::iterator_traits<TPointer>::value_type) * n));
+    return reinterpret_cast<T*>(memcpy(reinterpret_cast<void*>(db),
+                                       reinterpret_cast<const void*>(sb),
+                                       sizeof(typename etl::iterator_traits<T*>::value_type) * n));
   }
 
   //***************************************************************************
@@ -2296,13 +2317,13 @@ namespace etl
   /// \param source end
   /// \param destination begin
   //***************************************************************************
-  template <typename TPointer>
-  typename etl::enable_if<etl::is_trivially_copyable<typename etl::iterator_traits<TPointer>::value_type>::value, TPointer>::type
-    mem_move(const TPointer sb, const TPointer se, TPointer db) ETL_NOEXCEPT
+  template <typename T>
+  typename etl::enable_if<etl::is_trivially_copyable<typename etl::iterator_traits<T*>::value_type>::value, T*>::type
+    mem_move(const T* sb, const T* se, T* db) ETL_NOEXCEPT
   {
-    return reinterpret_cast<TPointer>(memmove(reinterpret_cast<void*>(db), 
-                                              reinterpret_cast<void*>(sb), 
-                                              sizeof(typename etl::iterator_traits<TPointer>::value_type) * static_cast<size_t>(se - sb)));
+    return reinterpret_cast<T*>(memmove(reinterpret_cast<void*>(db),
+                                        reinterpret_cast<const void*>(sb),
+                                        sizeof(typename etl::iterator_traits<T*>::value_type) * static_cast<size_t>(se - sb)));
   }
 
   //***************************************************************************
@@ -2312,32 +2333,32 @@ namespace etl
   /// \param source length
   /// \param destination begin
   //***************************************************************************
-  template <typename TPointer>
-  typename etl::enable_if<etl::is_trivially_copyable<typename etl::iterator_traits<TPointer>::value_type>::value, TPointer>::type
-    mem_move(const TPointer sb, size_t n, TPointer db) ETL_NOEXCEPT
+  template <typename T>
+  typename etl::enable_if<etl::is_trivially_copyable<typename etl::iterator_traits<T*>::value_type>::value, T*>::type
+    mem_move(const T* sb, size_t n, T* db) ETL_NOEXCEPT
   {
-    return reinterpret_cast<TPointer>(memmove(reinterpret_cast<void*>(db), 
-                                              reinterpret_cast<void*>(sb), 
-                                              sizeof(typename etl::iterator_traits<TPointer>::value_type) * n));
+    return reinterpret_cast<T*>(memmove(reinterpret_cast<void*>(db),
+                                        reinterpret_cast<const void*>(sb),
+                                        sizeof(typename etl::iterator_traits<T*>::value_type) * n));
   }
 
   //***************************************************************************
   /// Template wrapper for memcmp.
-  /// \param source begin
-  /// \param source end
-  /// \param destination begin
+  /// \param sb Source begin
+  /// \param se Source end
+  /// \param db Destination begin
   /// \return < 0	The first byte that does not match in both memory blocks has a lower value in 'sb' than in 'db' when evaluated as unsigned char values.
   ///   0 The contents of both memory blocks are equal
   /// > 0	The first byte that does not match in both memory blocks has a greater value in 'sb' than in 'db' when evaluated as unsigned char values.
   //***************************************************************************
-  template <typename TPointer>
+  template <typename T>
   ETL_NODISCARD
-    typename etl::enable_if<etl::is_trivially_copyable<typename etl::iterator_traits<TPointer>::value_type>::value, int>::type
-    mem_compare(const TPointer sb, const TPointer se, TPointer db) ETL_NOEXCEPT
+    typename etl::enable_if<etl::is_trivially_copyable<typename etl::iterator_traits<T*>::value_type>::value, int>::type
+    mem_compare(const T* sb, const T* se, const T* db) ETL_NOEXCEPT
   {
-    return memcmp(reinterpret_cast<void*>(db), 
-                  reinterpret_cast<void*>(sb), 
-                  sizeof(typename etl::iterator_traits<TPointer>::value_type) * static_cast<size_t>(se - sb));
+    return memcmp(reinterpret_cast<const void*>(db),
+                  reinterpret_cast<const void*>(sb),
+                  sizeof(typename etl::iterator_traits<T*>::value_type) * static_cast<size_t>(se - sb));
   }
 
   //***************************************************************************
@@ -2349,14 +2370,14 @@ namespace etl
   ///   0 The contents of both memory blocks are equal
   /// > 0	The first byte that does not match in both memory blocks has a greater value in 'sb' than in 'db' when evaluated as unsigned char values.
   //***************************************************************************
-  template <typename TPointer>
+  template <typename T>
   ETL_NODISCARD
-    typename etl::enable_if<etl::is_trivially_copyable<typename etl::iterator_traits<TPointer>::value_type>::value, int>::type
-    mem_compare(const TPointer sb, size_t n, TPointer db) ETL_NOEXCEPT
+    typename etl::enable_if<etl::is_trivially_copyable<typename etl::iterator_traits<T*>::value_type>::value, int>::type
+    mem_compare(const T* sb, size_t n, const T* db) ETL_NOEXCEPT
   {
-    return memcmp(reinterpret_cast<void*>(db), 
-                  reinterpret_cast<void*>(sb), 
-                  sizeof(typename etl::iterator_traits<TPointer>::value_type) * n);
+    return memcmp(reinterpret_cast<const void*>(db),
+                  reinterpret_cast<const void*>(sb),
+                  sizeof(typename etl::iterator_traits<T*>::value_type) * n);
   }
 
   //***************************************************************************
@@ -2384,7 +2405,7 @@ namespace etl
   //***************************************************************************
   template <typename TPointer, typename T>
   typename etl::enable_if<etl::is_trivially_copyable<typename etl::iterator_traits<TPointer>::value_type>::value, TPointer>::type
-    mem_set(const TPointer db, size_t n, T value) ETL_NOEXCEPT
+    mem_set(TPointer db, size_t n, T value) ETL_NOEXCEPT
   {
     return reinterpret_cast<TPointer>(memset(reinterpret_cast<void*>(db),
                                              static_cast<char>(value),
