@@ -225,7 +225,7 @@ namespace etl
         if (timer.id != etl::timer::id::NO_TIMER)
         {
           // Has a valid period.
-          if (timer.period != etl::timer::state::INACTIVE)
+          if (timer.period != etl::timer::state::Inactive)
           {
             ++process_semaphore;
             if (timer.is_active())
@@ -302,6 +302,36 @@ namespace etl
       return false;
     }
 
+    //*******************************************
+    /// Check if there is an active timer.
+    //*******************************************
+    bool has_active_timer() const
+    {
+      ++process_semaphore;
+      bool result = !active_list.empty();
+      --process_semaphore;
+
+      return result;
+    }
+
+    //*******************************************
+    /// Get the time to the next timer event.
+    /// Returns etl::timer::interval::No_Active_Interval if there is no active timer.
+    //*******************************************
+    uint32_t time_to_next() const
+    {
+      uint32_t delta = static_cast<uint32_t>(etl::timer::interval::No_Active_Interval);
+
+      ++process_semaphore;
+      if (!active_list.empty())
+      {
+        delta = active_list.front().delta;
+      }
+      --process_semaphore;
+
+      return delta;
+    }
+
   protected:
 
     //*************************************************************************
@@ -313,7 +343,7 @@ namespace etl
         : p_message(ETL_NULLPTR)
         , p_router(ETL_NULLPTR)
         , period(0U)
-        , delta(etl::timer::state::INACTIVE)
+        , delta(etl::timer::state::Inactive)
         , destination_router_id(etl::imessage_bus::ALL_MESSAGE_ROUTERS)
         , id(etl::timer::id::NO_TIMER)
         , previous(etl::timer::id::NO_TIMER)
@@ -332,7 +362,7 @@ namespace etl
         : p_message(&message_)
         , p_router(&irouter_)
         , period(period_)
-        , delta(etl::timer::state::INACTIVE)
+        , delta(etl::timer::state::Inactive)
         , destination_router_id(destination_router_id_)
         , id(id_)
         , previous(etl::timer::id::NO_TIMER)
@@ -346,7 +376,7 @@ namespace etl
       //*******************************************
       bool is_active() const
       {
-        return delta != etl::timer::state::INACTIVE;
+        return delta != etl::timer::state::Inactive;
       }
 
       //*******************************************
@@ -354,7 +384,7 @@ namespace etl
       //*******************************************
       void set_inactive()
       {
-        delta = etl::timer::state::INACTIVE;
+        delta = etl::timer::state::Inactive;
       }
 
       const etl::imessage*     p_message;
@@ -405,10 +435,10 @@ namespace etl
 
       //*******************************
       timer_list(timer_data* ptimers_)
-        : head(etl::timer::id::NO_TIMER),
-        tail(etl::timer::id::NO_TIMER),
-        current(etl::timer::id::NO_TIMER),
-        ptimers(ptimers_)
+        : head(etl::timer::id::NO_TIMER)
+        , tail(etl::timer::id::NO_TIMER)
+        , current(etl::timer::id::NO_TIMER)
+        , ptimers(ptimers_)
       {
       }
 
@@ -518,7 +548,7 @@ namespace etl
 
         timer.previous = etl::timer::id::NO_TIMER;
         timer.next = etl::timer::id::NO_TIMER;
-        timer.delta = etl::timer::state::INACTIVE;
+        timer.delta = etl::timer::state::Inactive;
       }
 
       //*******************************
@@ -527,6 +557,12 @@ namespace etl
         return ptimers[head];
       }
 
+      //*******************************
+      const timer_data& front() const
+      {
+        return ptimers[head];
+      }
+
       //*******************************
       etl::timer::id::type begin()
       {
@@ -581,7 +617,7 @@ namespace etl
     timer_list active_list;
 
     bool enabled;
-    TSemaphore process_semaphore;
+    mutable TSemaphore process_semaphore;
     uint_least8_t registered_timers;
 
   public:
