@@ -231,7 +231,7 @@ namespace etl
         if (timer.id != etl::timer::id::NO_TIMER)
         {
           // Has a valid period.
-          if (timer.period != etl::timer::state::INACTIVE)
+          if (timer.period != etl::timer::state::Inactive)
           {
             lock();
             if (timer.is_active())
@@ -318,6 +318,36 @@ namespace etl
       unlock   = unlock_;
     }
 
+    //*******************************************
+    /// Check if there is an active timer.
+    //*******************************************
+    bool has_active_timer() const
+    {
+      lock();
+      bool result = !active_list.empty();
+      unlock();
+
+      return result;
+    }
+
+    //*******************************************
+    /// Get the time to the next timer event.
+    /// Returns etl::timer::interval::No_Active_Interval if there is no active timer.
+    //*******************************************
+    uint32_t time_to_next() const
+    {
+      uint32_t delta = static_cast<uint32_t>(etl::timer::interval::No_Active_Interval);
+
+      lock();
+      if (!active_list.empty())
+      {
+        delta = active_list.front().delta;
+      }
+      unlock();
+
+      return delta;
+    }
+
   protected:
 
     //*************************************************************************
@@ -329,7 +359,7 @@ namespace etl
         : p_message(ETL_NULLPTR)
         , p_router(ETL_NULLPTR)
         , period(0)
-        , delta(etl::timer::state::INACTIVE)
+        , delta(etl::timer::state::Inactive)
         , destination_router_id(etl::imessage_bus::ALL_MESSAGE_ROUTERS)
         , id(etl::timer::id::NO_TIMER)
         , previous(etl::timer::id::NO_TIMER)
@@ -348,7 +378,7 @@ namespace etl
         : p_message(&message_)
         , p_router(&irouter_)
         , period(period_)
-        , delta(etl::timer::state::INACTIVE)
+        , delta(etl::timer::state::Inactive)
         , destination_router_id(destination_router_id_)
         , id(id_)
         , previous(etl::timer::id::NO_TIMER)
@@ -362,7 +392,7 @@ namespace etl
       //*******************************************
       bool is_active() const
       {
-        return delta != etl::timer::state::INACTIVE;
+        return delta != etl::timer::state::Inactive;
       }
 
       //*******************************************
@@ -370,7 +400,7 @@ namespace etl
       //*******************************************
       void set_inactive()
       {
-        delta = etl::timer::state::INACTIVE;
+        delta = etl::timer::state::Inactive;
       }
 
       const etl::imessage* p_message;
@@ -533,7 +563,7 @@ namespace etl
 
         timer.previous = etl::timer::id::NO_TIMER;
         timer.next = etl::timer::id::NO_TIMER;
-        timer.delta = etl::timer::state::INACTIVE;
+        timer.delta = etl::timer::state::Inactive;
       }
 
       //*******************************
@@ -542,6 +572,12 @@ namespace etl
         return ptimers[head];
       }
 
+      //*******************************
+      const timer_data& front() const
+      {
+        return ptimers[head];
+      }
+
       //*******************************
       etl::timer::id::type begin()
       {
