@@ -612,7 +612,7 @@ namespace etl
     size_type current_size;   ///< The number of the used nodes.
     const size_type CAPACITY; ///< The maximum size of the set.
     Node* root_node;          ///< The node that acts as the multiset root.
-    ETL_DECLARE_DEBUG_COUNT
+    ETL_DECLARE_DEBUG_COUNT;
   };
 
   //***************************************************************************
@@ -1448,6 +1448,8 @@ namespace etl
       // Skip if doing self assignment
       if (this != &rhs)
       {
+        clear();
+
         typename etl::imultiset<TKey, TCompare>::iterator from = rhs.begin();
 
         while (from != rhs.end())
@@ -1528,10 +1530,10 @@ namespace etl
     //*************************************************************************
     Data_Node& allocate_data_node(const_reference value)
     {
-      Data_Node& node = allocate_data_node();
-      ::new ((void*)&node.value) value_type(value);
-      ETL_INCREMENT_DEBUG_COUNT
-      return node;
+      Data_Node* node = allocate_data_node();
+      ::new ((void*)&node->value) value_type(value);
+      ETL_INCREMENT_DEBUG_COUNT;
+      return *node;
     }
 
 #if ETL_USING_CPP11
@@ -1540,20 +1542,20 @@ namespace etl
     //*************************************************************************
     Data_Node& allocate_data_node(rvalue_reference value)
     {
-      Data_Node& node = allocate_data_node();
-      ::new ((void*)&node.value) value_type(etl::move(value));
-      ETL_INCREMENT_DEBUG_COUNT
-      return node;
+      Data_Node* node = allocate_data_node();
+      ::new ((void*)&node->value) value_type(etl::move(value));
+      ETL_INCREMENT_DEBUG_COUNT;
+      return *node;
     }
 #endif
 
     //*************************************************************************
     /// Create a Data_Node.
     //*************************************************************************
-    Data_Node& allocate_data_node()
+    Data_Node* allocate_data_node()
     {
       Data_Node* (etl::ipool::*func)() = &etl::ipool::allocate<Data_Node>;
-      return *(p_node_pool->*func)();
+      return (p_node_pool->*func)();
     }
 
     //*************************************************************************
@@ -1563,7 +1565,7 @@ namespace etl
     {
       node.value.~value_type();
       p_node_pool->release(&node);
-      ETL_DECREMENT_DEBUG_COUNT
+      ETL_DECREMENT_DEBUG_COUNT;
     }
 
     //*************************************************************************
@@ -2438,7 +2440,7 @@ namespace etl
   template <typename TKey, typename TKeyCompare = etl::less<TKey>, typename... T>
   constexpr auto make_multiset(T&&... keys) -> etl::multiset<TKey, sizeof...(T), TKeyCompare>
   {
-    return { {etl::forward<T>(keys)...} };
+    return { etl::forward<T>(keys)... };
   }
 #endif
 
