@@ -369,6 +369,20 @@ namespace etl
       return emplace_implementation(value1, value2, value3, value4);
     }
 
+    //*************************************************************************
+    /// Constructs a value in the queue 'in place'.
+    //*************************************************************************
+    bool emplace()
+    {
+      this->lock();
+
+      bool result = emplace_implementation();
+
+      this->unlock();
+
+      return result;
+    }
+
     //*************************************************************************
     /// Constructs a value in the queue 'in place'.
     //*************************************************************************
