@@ -1,4 +1,4 @@
-﻿///\file
+///\file
 
 /******************************************************************************
 The MIT License(MIT)
@@ -462,10 +462,12 @@ namespace etl
 
     random_pcg()
     {
+#include "private/diagnostic_useless_cast_push.h"
       // An attempt to come up with a unique non-zero seed,
       // based on the address of the instance.
       uintptr_t n = reinterpret_cast<uintptr_t>(this);
       value = static_cast<uint64_t>(n);
+#include "private/diagnostic_pop.h"
     }
 
     //***************************************************************************
