@@ -71,8 +71,10 @@ namespace etl
     typedef T*                               pointer;
     typedef const T*                         const_pointer;
 
-    typedef T*                                     iterator;
-    typedef ETL_OR_STD::reverse_iterator<iterator> reverse_iterator;
+    typedef T*                                           iterator;
+    typedef const T*                                     const_iterator;
+    typedef ETL_OR_STD::reverse_iterator<iterator>       reverse_iterator;
+    typedef ETL_OR_STD::reverse_iterator<const_iterator> const_reverse_iterator;
 
     typedef etl::circular_iterator<pointer>                                circular_iterator;
     typedef etl::circular_iterator<ETL_OR_STD::reverse_iterator<pointer> > reverse_circular_iterator;
@@ -84,7 +86,7 @@ namespace etl
     //*************************************************************************
     template <typename TIterator, typename TSize>
     ETL_CONSTEXPR explicit span(const TIterator begin_, const TSize /*size_*/) ETL_NOEXCEPT
-      : pbegin(etl::addressof(*begin_))
+      : pbegin(etl::to_address(begin_))
     {
     }
 
@@ -93,7 +95,7 @@ namespace etl
     //*************************************************************************
     template <typename TIterator>
     ETL_CONSTEXPR explicit span(const TIterator begin_, const TIterator /*end_*/)
-      : pbegin(etl::addressof(*begin_))
+      : pbegin(etl::to_address(begin_))
     {
     }
 
@@ -185,6 +187,14 @@ namespace etl
       return pbegin;
     }
 
+    //*************************************************************************
+    /// Returns a const iterator to the beginning of the span.
+    //*************************************************************************
+    ETL_NODISCARD ETL_CONSTEXPR const_iterator cbegin() const ETL_NOEXCEPT
+    {
+      return pbegin;
+    }
+
     //*************************************************************************
     /// Returns an iterator to the beginning of the span.
     //*************************************************************************
@@ -201,6 +211,14 @@ namespace etl
       return circular_iterator(begin(), end());
     }
 
+    //*************************************************************************
+    /// Returns a const iterator to the end of the span.
+    //*************************************************************************
+    ETL_NODISCARD ETL_CONSTEXPR const_iterator cend() const ETL_NOEXCEPT
+    {
+      return (pbegin + Extent);
+    }
+
     //*************************************************************************
     /// Returns an iterator to the end of the span.
     //*************************************************************************
@@ -209,6 +227,14 @@ namespace etl
       return (pbegin + Extent);
     }
 
+    //*************************************************************************
+    // Returns a const reverse iterator to the reverse beginning of the span.
+    //*************************************************************************
+    ETL_NODISCARD ETL_CONSTEXPR const_reverse_iterator crbegin() const ETL_NOEXCEPT
+    {
+      return const_reverse_iterator((pbegin + Extent));
+    }
+
     //*************************************************************************
     // Returns an reverse iterator to the reverse beginning of the span.
     //*************************************************************************
@@ -225,6 +251,14 @@ namespace etl
       return reverse_circular_iterator(rbegin(), rend());
     }
 
+    //*************************************************************************
+    /// Returns a const reverse iterator to the end of the span.
+    //*************************************************************************
+    ETL_NODISCARD ETL_CONSTEXPR const_reverse_iterator crend() const ETL_NOEXCEPT
+    {
+      return const_reverse_iterator(pbegin);
+    }
+
     //*************************************************************************
     /// Returns a reverse iterator to the end of the span.
     //*************************************************************************
@@ -238,7 +272,7 @@ namespace etl
     //*************************************************************************
     ETL_NODISCARD ETL_CONSTEXPR bool empty() const ETL_NOEXCEPT
     {
-      return false;
+      return Extent == 0;
     }
 
     //*************************************************************************
@@ -272,6 +306,26 @@ namespace etl
     {
       pbegin = other.pbegin;
       return *this;
+    } 
+
+    //*************************************************************************
+    /// Returns a reference to the value at index 'i'.
+    //*************************************************************************
+    ETL_NODISCARD ETL_CONSTEXPR14 reference at(size_t i)
+    {
+      ETL_ASSERT(i < size(), ETL_ERROR(array_out_of_range));
+
+      return pbegin[i];
+    }
+
+    //*************************************************************************
+    /// Returns a const reference to the value at index 'i'.
+    //*************************************************************************
+    ETL_NODISCARD ETL_CONSTEXPR14 const_reference at(size_t i) const
+    {
+      ETL_ASSERT(i < size(), ETL_ERROR(array_out_of_range));
+
+      return pbegin[i];
     }
 
     //*************************************************************************
@@ -377,6 +431,16 @@ namespace etl
     pointer pbegin;
   };
 
+  //*************************************************************************
+  /// Pseudo constructor for constructing from C array without explicitly
+  /// specifying type and size
+  //*************************************************************************
+  template <typename T, size_t Extent>
+  ETL_CONSTEXPR span<T, Extent> make_span(T (&data)[Extent])
+  {
+    return span<T, Extent>(data);
+  }
+
   //***************************************************************************
   /// Span - Dynamic Extent
   //***************************************************************************
@@ -393,8 +457,10 @@ namespace etl
     typedef T*       pointer;
     typedef const T* const_pointer;
     
-    typedef T*                                     iterator;
-    typedef ETL_OR_STD::reverse_iterator<iterator> reverse_iterator;
+    typedef T*                                           iterator;
+    typedef const T*                                     const_iterator;
+    typedef ETL_OR_STD::reverse_iterator<iterator>       reverse_iterator;
+    typedef ETL_OR_STD::reverse_iterator<const_iterator> const_reverse_iterator;
 
     typedef etl::circular_iterator<pointer>                                circular_iterator;
     typedef etl::circular_iterator<ETL_OR_STD::reverse_iterator<pointer> > reverse_circular_iterator;
@@ -415,8 +481,8 @@ namespace etl
     //*************************************************************************
     template <typename TIterator, typename TSize>
     ETL_CONSTEXPR span(const TIterator begin_, const TSize size_) ETL_NOEXCEPT
-      : pbegin(etl::addressof(*begin_))
-      , pend(etl::addressof(*begin_) + size_)
+      : pbegin(etl::to_address(begin_))
+      , pend(etl::to_address(begin_) + size_)
     {
     }
 
@@ -425,8 +491,8 @@ namespace etl
     //*************************************************************************
     template <typename TIterator>
     ETL_CONSTEXPR span(const TIterator begin_, const TIterator end_)
-      : pbegin(etl::addressof(*begin_))
-      , pend(etl::addressof(*begin_) + etl::distance(begin_, end_))
+      : pbegin(etl::to_address(begin_))
+      , pend(etl::to_address(begin_) + etl::distance(begin_, end_))
     {
     }
 
@@ -524,6 +590,14 @@ namespace etl
       return pbegin;
     }
 
+    //*************************************************************************
+    /// Returns a const iterator to the beginning of the span.
+    //*************************************************************************
+    ETL_NODISCARD ETL_CONSTEXPR const_iterator cbegin() const ETL_NOEXCEPT
+    {
+      return pbegin;
+    }
+
     //*************************************************************************
     /// Returns an iterator to the beginning of the span.
     //*************************************************************************
@@ -540,6 +614,14 @@ namespace etl
       return circular_iterator(begin(), end());
     }
 
+    //*************************************************************************
+    /// Returns a const iterator to the end of the span.
+    //*************************************************************************
+    ETL_NODISCARD ETL_CONSTEXPR const_iterator cend() const ETL_NOEXCEPT
+    {
+      return pend;
+    }
+
     //*************************************************************************
     /// Returns an iterator to the end of the span.
     //*************************************************************************
@@ -556,6 +638,14 @@ namespace etl
       return reverse_iterator(pend);
     }
 
+    //*************************************************************************
+    // Returns a const reverse iterator to the reverse beginning of the span.
+    //*************************************************************************
+    ETL_NODISCARD ETL_CONSTEXPR const_reverse_iterator crbegin() const ETL_NOEXCEPT
+    {
+      return const_reverse_iterator(pend);
+    }
+
     //*************************************************************************
     /// Returns a reverse circular iterator to the end of the span.
     //*************************************************************************
@@ -564,6 +654,14 @@ namespace etl
       return reverse_circular_iterator(rbegin(), rend());
     }
 
+    //*************************************************************************
+    /// Returns a const reverse iterator to the end of the span.
+    //*************************************************************************
+    ETL_NODISCARD ETL_CONSTEXPR const_reverse_iterator crend() const ETL_NOEXCEPT
+    {
+      return const_reverse_iterator(pbegin);
+    }
+
     //*************************************************************************
     /// Returns a reverse iterator to the end of the span.
     //*************************************************************************
@@ -614,6 +712,26 @@ namespace etl
       return *this;
     }
 
+    //*************************************************************************
+    /// Returns a reference to the value at index 'i'.
+    //*************************************************************************
+    ETL_NODISCARD ETL_CONSTEXPR14 reference at(size_t i)
+    {
+      ETL_ASSERT(i < size(), ETL_ERROR(array_out_of_range));
+
+      return pbegin[i];
+    }
+
+    //*************************************************************************
+    /// Returns a const reference to the value at index 'i'.
+    //*************************************************************************
+    ETL_NODISCARD ETL_CONSTEXPR14 const_reference at(size_t i) const
+    {
+      ETL_ASSERT(i < size(), ETL_ERROR(array_out_of_range));
+
+      return pbegin[i];
+    }
+
     //*************************************************************************
     /// Returns a reference to the indexed value.
     //*************************************************************************
@@ -700,6 +818,26 @@ namespace etl
     pointer pend;
   };
 
+  //*************************************************************************
+  /// Pseudo constructor for constructing from container without explicitly
+  /// specifying type and size
+  //*************************************************************************
+  template <typename T>
+  ETL_CONSTEXPR span<typename T::value_type, etl::dynamic_extent> make_span(T& data)
+  {
+    return span<typename T::value_type, etl::dynamic_extent>(data);
+  }
+
+  //*************************************************************************
+  /// Pseudo constructor for constructing from const container without
+  /// explicitly specifying type and size
+  //*************************************************************************
+  template <typename T>
+  ETL_CONSTEXPR span<typename T::value_type const, etl::dynamic_extent> make_span(const T& data)
+  {
+    return span<typename T::value_type const, etl::dynamic_extent>(data);
+  }
+
   template <typename T, size_t Extent>
   ETL_CONSTANT size_t span<T, Extent>::extent;
 
