@@ -72,6 +72,7 @@ namespace etl
     typedef istring interface_type;
 
     typedef istring::value_type value_type;
+    typedef istring::size_type  size_type;
 
     static ETL_CONSTANT size_t MAX_SIZE = MAX_SIZE_;
 
@@ -243,6 +244,16 @@ namespace etl
       return *this;
     }
 
+    //*************************************************************************
+    /// Assignment operator.
+    //*************************************************************************
+    string& operator = (const etl::string_view& view)
+    {
+      this->assign(view);
+
+      return *this;
+    }
+
     //*************************************************************************
     /// Fix the internal pointers after a low level memory copy.
     //*************************************************************************
@@ -261,7 +272,7 @@ namespace etl
   };
 
   template <size_t MAX_SIZE_>
-  ETL_CONSTANT size_t string<MAX_SIZE_>::MAX_SIZE;
+  ETL_CONSTANT typename string<MAX_SIZE_>::size_type string<MAX_SIZE_>::MAX_SIZE;
 
   //***************************************************************************
   /// A string implementation that uses a fixed size external buffer.
@@ -361,6 +372,16 @@ namespace etl
       this->resize(count, c);
     }
 
+    //*************************************************************************
+    /// From string_view.
+    ///\param view The string_view.
+    //*************************************************************************
+    explicit string_ext(const etl::string_view& view, value_type* buffer, size_type buffer_size)
+      : istring(buffer, buffer_size - 1U)
+    {
+      this->assign(view.begin(), view.end());
+    }
+
     //*************************************************************************
     /// Constructor, from an iterator range.
     ///\tparam TIterator The iterator type.
@@ -385,16 +406,6 @@ namespace etl
     }
 #endif
 
-    //*************************************************************************
-    /// From string_view.
-    ///\param view The string_view.
-    //*************************************************************************
-    explicit string_ext(const etl::string_view& view, value_type* buffer, size_type buffer_size)
-      : istring(buffer, buffer_size - 1U)
-    {
-      this->assign(view.begin(), view.end());
-    }
-
     //*************************************************************************
     /// Assignment operator.
     //*************************************************************************
@@ -408,7 +419,6 @@ namespace etl
       return *this;
     }
 
-
     //*************************************************************************
     /// Assignment operator.
     //*************************************************************************
@@ -432,6 +442,16 @@ namespace etl
       return *this;
     }
 
+    //*************************************************************************
+    /// Assignment operator.
+    //*************************************************************************
+    string_ext& operator = (const etl::string_view& view)
+    {
+      this->assign(view);
+
+      return *this;
+    }
+
     //*************************************************************************
     /// Fix the internal pointers after a low level memory copy.
     //*************************************************************************
