@@ -244,6 +244,16 @@ namespace etl
       return *this;
     }
 
+    //*************************************************************************
+    /// Assignment operator.
+    //*************************************************************************
+    u8string& operator = (const etl::u8string_view& view)
+    {
+      this->assign(view);
+
+      return *this;
+    }
+
     //*************************************************************************
     /// Fix the internal pointers after a low level memory copy.
     //*************************************************************************
@@ -409,7 +419,6 @@ namespace etl
       return *this;
     }
 
-
     //*************************************************************************
     /// Assignment operator.
     //*************************************************************************
@@ -433,6 +442,16 @@ namespace etl
       return *this;
     }
 
+    //*************************************************************************
+    /// Assignment operator.
+    //*************************************************************************
+    u8string_ext& operator = (const etl::u8string_view& view)
+    {
+      this->assign(view);
+
+      return *this;
+    }
+
     //*************************************************************************
     /// Fix the internal pointers after a low level memory copy.
     //*************************************************************************
