@@ -51,6 +51,8 @@ SOFTWARE.
 #include "placement_new.h"
 #include "initializer_list.h"
 
+#include "private/comparator_is_transparent.h"
+
 #include <stddef.h>
 
 //*****************************************************************************
@@ -588,6 +590,18 @@ namespace etl
       return key_hash_function(key) % number_of_buckets;
     }
 
+#if ETL_USING_CPP11
+    //*********************************************************************
+    /// Returns the bucket index for the key.
+    ///\return The bucket index for the key.
+    //*********************************************************************
+    template <typename K, typename KE = TKeyEqual, etl::enable_if_t<comparator_is_transparent<KE>::value, int> = 0>
+    size_type get_bucket_index(const K& key) const
+    {
+      return key_hash_function(key) % number_of_buckets;
+    }
+#endif
+
     //*********************************************************************
     /// Returns the size of the bucket key.
     ///\return The bucket size of the bucket key.
@@ -599,6 +613,20 @@ namespace etl
       return etl::distance(pbuckets[index].begin(), pbuckets[index].end());
     }
 
+#if ETL_USING_CPP11
+    //*********************************************************************
+    /// Returns the size of the bucket key.
+    ///\return The bucket size of the bucket key.
+    //*********************************************************************
+    template <typename K, typename KE = TKeyEqual, etl::enable_if_t<comparator_is_transparent<KE>::value, int> = 0>
+    size_type bucket_size(const K& key) const
+    {
+      size_t index = bucket(key);
+
+      return etl::distance(pbuckets[index].begin(), pbuckets[index].end());
+    }
+#endif
+
     //*********************************************************************
     /// Returns the maximum number of the buckets the container can hold.
     ///\return The maximum number of the buckets the container can hold.
@@ -712,6 +740,79 @@ namespace etl
       return result;
     }
 
+#if ETL_USING_CPP11
+    //*********************************************************************
+    /// Inserts a value to the unordered_multiset.
+    /// If asserts or exceptions are enabled, emits unordered_multiset_full if the unordered_multiset is already full.
+    ///\param value The value to insert.
+    //*********************************************************************
+    template <typename K, typename KE = TKeyEqual, etl::enable_if_t<comparator_is_transparent<KE>::value, int> = 0>
+    ETL_OR_STD::pair<iterator, bool> insert(const K& key)
+    {
+      ETL_OR_STD::pair<iterator, bool> result(end(), false);
+
+      ETL_ASSERT(!full(), ETL_ERROR(unordered_multiset_full));
+
+      // Get the hash index.
+      size_t index = get_bucket_index(key);
+
+      // Get the bucket & bucket iterator.
+      bucket_t* pbucket = pbuckets + index;
+      bucket_t& bucket = *pbucket;
+
+      // The first one in the bucket?
+      if (bucket.empty())
+      {
+        // Get a new node.
+        node_t* node = allocate_data_node();
+        node->clear();
+        ::new (&node->key) value_type(key);
+        ETL_INCREMENT_DEBUG_COUNT;
+
+        // Just add the pointer to the bucket;
+        bucket.insert_after(bucket.before_begin(), *node);
+        adjust_first_last_markers_after_insert(&bucket);
+
+        result.first = iterator((pbuckets + number_of_buckets), pbucket, pbucket->begin());
+        result.second = true;
+      }
+      else
+      {
+        // Step though the bucket looking for a place to insert.
+        local_iterator inode_previous = bucket.before_begin();
+        local_iterator inode = bucket.begin();
+
+        while (inode != bucket.end())
+        {
+          // Do we already have this key?
+          if (key_equal_function(inode->key, key))
+          {
+            break;
+          }
+
+          ++inode_previous;
+          ++inode;
+        }
+
+        // Get a new node.
+        node_t* node = allocate_data_node();
+        node->clear();
+        ::new (&node->key) value_type(key);
+        ETL_INCREMENT_DEBUG_COUNT;
+
+        // Add the node to the end of the bucket;
+        bucket.insert_after(inode_previous, *node);
+        adjust_first_last_markers_after_insert(&bucket);
+        ++inode_previous;
+
+        result.first = iterator((pbuckets + number_of_buckets), pbucket, inode_previous);
+        result.second = true;
+      }
+
+      return result;
+    }
+#endif
+
 #if ETL_USING_CPP11
     //*********************************************************************
     /// Inserts a value to the unordered_multiset.
@@ -846,6 +947,43 @@ namespace etl
       return n;
     }
 
+#if ETL_USING_CPP11
+    //*********************************************************************
+    /// Erases an element.
+    ///\param key The key to erase.
+    ///\return The number of elements erased. 0 or 1.
+    //*********************************************************************
+    template <typename K, typename KE = TKeyEqual, etl::enable_if_t<comparator_is_transparent<KE>::value, int> = 0>
+    size_t erase(const K& key)
+    {
+      size_t n = 0UL;
+      size_t bucket_id = get_bucket_index(key);
+
+      bucket_t& bucket = pbuckets[bucket_id];
+
+      local_iterator iprevious = bucket.before_begin();
+      local_iterator icurrent = bucket.begin();
+
+      while (icurrent != bucket.end())
+      {
+        if (key_equal_function(icurrent->key, key))
+        {
+          delete_data_node(iprevious, icurrent, bucket);
+          ++n;
+          icurrent = iprevious;
+        }
+        else
+        {
+          ++iprevious;
+        }
+
+        ++icurrent;
+      }
+
+      return n;
+    }
+#endif
+
     //*********************************************************************
     /// Erases an element.
     ///\param ielement Iterator to the element.
@@ -963,6 +1101,35 @@ namespace etl
       return n;
     }
 
+#if ETL_USING_CPP11
+    //*********************************************************************
+    /// Counts an element.
+    ///\param key The key to search for.
+    ///\return 1 if the key exists, otherwise 0.
+    //*********************************************************************
+    template <typename K, typename KE = TKeyEqual, etl::enable_if_t<comparator_is_transparent<KE>::value, int> = 0>
+    size_t count(const K& key) const
+    {
+      size_t n = 0UL;
+      const_iterator f = find(key);
+      const_iterator l = f;
+
+      if (l != end())
+      {
+        ++l;
+        ++n;
+
+        while ((l != end()) && key_equal_function(key, *l))
+        {
+          ++l;
+          ++n;
+        }
+      }
+
+      return n;
+    }
+#endif
+
     //*********************************************************************
     /// Finds an element.
     ///\param key The key to search for.
@@ -997,6 +1164,43 @@ namespace etl
       return end();
     }
 
+#if ETL_USING_CPP11
+    //*********************************************************************
+    /// Finds an element.
+    ///\param key The key to search for.
+    ///\return An iterator to the element if the key exists, otherwise end().
+    //*********************************************************************
+    template <typename K, typename KE = TKeyEqual, etl::enable_if_t<comparator_is_transparent<KE>::value, int> = 0>
+    iterator find(const K& key)
+    {
+      size_t index = get_bucket_index(key);
+
+      bucket_t* pbucket = pbuckets + index;
+      bucket_t& bucket = *pbucket;
+
+      // Is the bucket not empty?
+      if (!bucket.empty())
+      {
+        // Step though the list until we find the end or an equivalent key.
+        local_iterator inode = bucket.begin();
+        local_iterator iend = bucket.end();
+
+        while (inode != iend)
+        {
+          // Do we have this one?
+          if (key_equal_function(key, inode->key))
+          {
+            return iterator((pbuckets + number_of_buckets), pbucket, inode);
+          }
+
+          ++inode;
+        }
+      }
+
+      return end();
+    }
+#endif
+
     //*********************************************************************
     /// Finds an element.
     ///\param key The key to search for.
@@ -1031,6 +1235,43 @@ namespace etl
       return end();
     }
 
+#if ETL_USING_CPP11
+    //*********************************************************************
+    /// Finds an element.
+    ///\param key The key to search for.
+    ///\return An iterator to the element if the key exists, otherwise end().
+    //*********************************************************************
+    template <typename K, typename KE = TKeyEqual, etl::enable_if_t<comparator_is_transparent<KE>::value, int> = 0>
+    const_iterator find(const K& key) const
+    {
+      size_t index = get_bucket_index(key);
+
+      bucket_t* pbucket = pbuckets + index;
+      bucket_t& bucket = *pbucket;
+
+      // Is the bucket not empty?
+      if (!bucket.empty())
+      {
+        // Step though the list until we find the end or an equivalent key.
+        local_iterator inode = bucket.begin();
+        local_iterator iend = bucket.end();
+
+        while (inode != iend)
+        {
+          // Do we have this one?
+          if (key_equal_function(key, inode->key))
+          {
+            return iterator((pbuckets + number_of_buckets), pbucket, inode);
+          }
+
+          ++inode;
+        }
+      }
+
+      return end();
+    }
+#endif
+    
     //*********************************************************************
     /// Returns a range containing all elements with key key in the container.
     /// The range is defined by two iterators, the first pointing to the first
@@ -1057,6 +1298,35 @@ namespace etl
       return ETL_OR_STD::pair<iterator, iterator>(f, l);
     }
 
+#if ETL_USING_CPP11
+    //*********************************************************************
+    /// Returns a range containing all elements with key key in the container.
+    /// The range is defined by two iterators, the first pointing to the first
+    /// element of the wanted range and the second pointing past the last
+    /// element of the range.
+    ///\param key The key to search for.
+    ///\return An iterator pair to the range of elements if the key exists, otherwise end().
+    //*********************************************************************
+    template <typename K, typename KE = TKeyEqual, etl::enable_if_t<comparator_is_transparent<KE>::value, int> = 0>
+    ETL_OR_STD::pair<iterator, iterator> equal_range(const K& key)
+    {
+      iterator f = find(key);
+      iterator l = f;
+
+      if (l != end())
+      {
+        ++l;
+
+        while ((l != end()) && key_equal_function(key, *l))
+        {
+          ++l;
+        }
+      }
+
+      return ETL_OR_STD::pair<iterator, iterator>(f, l);
+    }
+#endif
+
     //*********************************************************************
     /// Returns a range containing all elements with key key in the container.
     /// The range is defined by two iterators, the first pointing to the first
@@ -1083,6 +1353,35 @@ namespace etl
       return ETL_OR_STD::pair<const_iterator, const_iterator>(f, l);
     }
 
+#if ETL_USING_CPP11
+    //*********************************************************************
+    /// Returns a range containing all elements with key key in the container.
+    /// The range is defined by two iterators, the first pointing to the first
+    /// element of the wanted range and the second pointing past the last
+    /// element of the range.
+    ///\param key The key to search for.
+    ///\return A const iterator pair to the range of elements if the key exists, otherwise end().
+    //*********************************************************************
+    template <typename K, typename KE = TKeyEqual, etl::enable_if_t<comparator_is_transparent<KE>::value, int> = 0>
+    ETL_OR_STD::pair<const_iterator, const_iterator> equal_range(const K& key) const
+    {
+      const_iterator f = find(key);
+      const_iterator l = f;
+
+      if (l != end())
+      {
+        ++l;
+
+        while ((l != end()) && key_equal_function(key, *l))
+        {
+          ++l;
+        }
+      }
+
+      return ETL_OR_STD::pair<const_iterator, const_iterator>(f, l);
+    }
+#endif
+
     //*************************************************************************
     /// Gets the size of the unordered_multiset.
     //*************************************************************************
@@ -1194,6 +1493,25 @@ namespace etl
     }
 #endif
 
+    //*************************************************************************
+    /// Check if the unordered_multiset contains the key.
+    //*************************************************************************
+    bool contains(key_parameter_t key) const
+    {
+      return find(key) != end();
+    }
+
+#if ETL_USING_CPP11
+    //*************************************************************************
+    /// Check if the unordered_map contains the key.
+    //*************************************************************************
+    template <typename K, typename KE = TKeyEqual, etl::enable_if_t<comparator_is_transparent<KE>::value, int> = 0>
+    bool contains(const K& key) const
+    {
+      return find(key) != end();
+    }
+#endif
+
   protected:
 
     //*********************************************************************
