@@ -190,6 +190,15 @@ namespace
       CHECK_EQUAL(std::distance(data.begin(), expected), std::distance(data.begin(), result));
     }
 
+    //*************************************************************************
+    TEST(min_element_empty)
+    {
+      Vector dataEmpty;
+      Vector::iterator expected = std::min_element(dataEmpty.begin(), dataEmpty.end());
+      Vector::iterator result = etl::min_element(dataEmpty.begin(), dataEmpty.end());
+      CHECK_EQUAL(std::distance(dataEmpty.end(), expected), std::distance(dataEmpty.end(), result));
+    }
+
     //*************************************************************************
     TEST(max_element)
     {
@@ -206,6 +215,15 @@ namespace
       CHECK_EQUAL(std::distance(data.begin(), expected), std::distance(data.begin(), result));
     }
 
+    //*************************************************************************
+    TEST(max_element_empty)
+    {
+      Vector dataEmpty;
+      Vector::iterator expected = std::max_element(dataEmpty.begin(), dataEmpty.end());
+      Vector::iterator result = etl::max_element(dataEmpty.begin(), dataEmpty.end());
+      CHECK_EQUAL(std::distance(dataEmpty.end(), expected), std::distance(dataEmpty.end(), result));
+    }
+
     //*************************************************************************
     TEST(minmax_element)
     {
@@ -224,6 +242,16 @@ namespace
       CHECK_EQUAL(std::distance(data.begin(), expected.second), std::distance(data.begin(), result.second));
     }
 
+    //*************************************************************************
+    TEST(minmax_element_empty)
+    {
+      Vector dataEmpty;
+      std::pair<Vector::iterator, Vector::iterator> expected = std::minmax_element(dataEmpty.begin(), dataEmpty.end());
+      std::pair<Vector::iterator, Vector::iterator> result = etl::minmax_element(dataEmpty.begin(), dataEmpty.end());
+      CHECK_EQUAL(std::distance(dataEmpty.begin(), expected.first), std::distance(dataEmpty.begin(), result.first));
+      CHECK_EQUAL(std::distance(dataEmpty.begin(), expected.second), std::distance(dataEmpty.begin(), result.second));
+    }
+
     //*************************************************************************
     TEST(minmax)
     {
@@ -1982,10 +2010,10 @@ namespace
       {
         std::shuffle(data.begin(), data.end(), urng);
 
-        std::forward_list<int> data1(data.begin(), data.end());
+        std::vector<int>       data1(data.begin(), data.end());
         std::forward_list<int> data2(data.begin(), data.end());
 
-        data1.sort();
+        std::sort(data1.begin(), data1.end());
         etl::selection_sort(data2.begin(), data2.end());
 
         bool is_same = std::equal(data1.begin(), data1.end(), data2.begin());
