@@ -1493,6 +1493,14 @@ namespace
       CHECK_EQUAL("...*..*...**.*...*.*.**..****...", stdtext.c_str());
     }
 
+    //*************************************************************************
+    TEST(test_global_size)
+    {
+      etl::bitset<32> b(0x12345678UL);
+
+      CHECK_EQUAL(32, ETL_OR_STD17::size(b));
+    }
+
     //*************************************************************************
     TEST(test_issue_497_count_inverted_bits)
     {
