@@ -1318,10 +1318,12 @@ namespace
 
       static std::vector<char> result;
 
-      etl::byte_stream_writer::callback_type callback([&](etl::byte_stream_writer::callback_parameter_type sp) 
-                                                      { 
-                                                        std::copy(sp.begin(), sp.end(), std::back_inserter(result));
-                                                      });
+      auto lambda = [&](etl::byte_stream_writer::callback_parameter_type sp) 
+        { 
+          std::copy(sp.begin(), sp.end(), std::back_inserter(result));
+        };
+
+      etl::byte_stream_writer::callback_type callback(lambda);
 
       etl::byte_stream_writer writer(storage.data(), storage.size(), etl::endian::big, callback);
 
