@@ -49,11 +49,11 @@ namespace
   //***************************************************************************
   // Class callback via etl::function
   //***************************************************************************
-  class Test
+  class Object
   {
   public:
 
-    Test()
+    Object()
       : p_controller(nullptr)
     {
     }
@@ -81,9 +81,9 @@ namespace
     etl::callback_timer<3>* p_controller;
   };
 
-  Test test;
-  etl::function_imv<Test, test, &Test::callback>  member_callback;
-  etl::function_imv<Test, test, &Test::callback2> member_callback2;
+  Object object;
+  etl::function_imv<Object, object, &Object::callback>  member_callback;
+  etl::function_imv<Object, object, &Object::callback2> member_callback2;
 
   //***************************************************************************
   // Free function callback via etl::function
@@ -114,16 +114,16 @@ namespace
     {
       etl::callback_timer<2> timer_controller;
 
-      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,        37, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback, 23, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id3 = timer_controller.register_timer(free_callback2,         11, etl::timer::mode::SINGLE_SHOT);
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,        37, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback, 23, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id3 = timer_controller.register_timer(free_callback2,         11, etl::timer::mode::Single_Shot);
 
       CHECK(id1 != etl::timer::id::NO_TIMER);
       CHECK(id2 != etl::timer::id::NO_TIMER);
       CHECK(id3 == etl::timer::id::NO_TIMER);
 
       timer_controller.clear();
-      id3 = timer_controller.register_timer(free_callback2, 11, etl::timer::mode::SINGLE_SHOT);
+      id3 = timer_controller.register_timer(free_callback2, 11, etl::timer::mode::Single_Shot);
       CHECK(id3 != etl::timer::id::NO_TIMER);
     }
 
@@ -132,11 +132,11 @@ namespace
     {
       etl::callback_timer<4> timer_controller;
 
-      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,        37, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback, 23, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id3 = timer_controller.register_timer(free_callback2,         11, etl::timer::mode::SINGLE_SHOT);
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,        37, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback, 23, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id3 = timer_controller.register_timer(free_callback2,         11, etl::timer::mode::Single_Shot);
 
-      test.tick_list.clear();
+      object.tick_list.clear();
       free_tick_list1.clear();
       free_tick_list2.clear();
 
@@ -160,11 +160,11 @@ namespace
       std::vector<uint64_t> compare2 = { 23 };
       std::vector<uint64_t> compare3 = { 11 };
 
-      CHECK(test.tick_list.size() != 0);
+      CHECK(object.tick_list.size() != 0);
       CHECK(free_tick_list1.size() != 0);
       CHECK(free_tick_list2.size() != 0);
 
-      CHECK_ARRAY_EQUAL(compare1.data(), test.tick_list.data(),  compare1.size());
+      CHECK_ARRAY_EQUAL(compare1.data(), object.tick_list.data(),  compare1.size());
       CHECK_ARRAY_EQUAL(compare2.data(), free_tick_list1.data(), compare2.size());
       CHECK_ARRAY_EQUAL(compare3.data(), free_tick_list2.data(), compare3.size());
     }
@@ -174,8 +174,8 @@ namespace
     {
       etl::callback_timer<1> timer_controller;
 
-      etl::timer::id::type id1 = timer_controller.register_timer(member_callback, 37, etl::timer::mode::SINGLE_SHOT);
-      test.tick_list.clear();
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback, 37, etl::timer::mode::Single_Shot);
+      object.tick_list.clear();
 
       timer_controller.start(id1);
       timer_controller.enable(true);
@@ -195,7 +195,7 @@ namespace
       CHECK(timer_controller.set_period(id1, 50));
       timer_controller.start(id1);
 
-      test.tick_list.clear();
+      object.tick_list.clear();
 
       ticks = 0;
 
@@ -207,7 +207,7 @@ namespace
 
       // Timer should have timed out.
 
-      CHECK_EQUAL(50U, *test.tick_list.data());
+      CHECK_EQUAL(50U, *object.tick_list.data());
 
       CHECK(timer_controller.unregister_timer(id1));
       CHECK(!timer_controller.unregister_timer(id1));
@@ -220,11 +220,11 @@ namespace
     {
       etl::callback_timer<3> timer_controller;
 
-      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,        37, etl::timer::mode::REPEATING);
-      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback, 23, etl::timer::mode::REPEATING);
-      etl::timer::id::type id3 = timer_controller.register_timer(free_callback2,         11, etl::timer::mode::REPEATING);
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,        37, etl::timer::mode::Repeating);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback, 23, etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = timer_controller.register_timer(free_callback2,         11, etl::timer::mode::Repeating);
 
-      test.tick_list.clear();
+      object.tick_list.clear();
       free_tick_list1.clear();
       free_tick_list2.clear();
 
@@ -248,11 +248,11 @@ namespace
       std::vector<uint64_t> compare2 = { 23, 46, 69, 92 };
       std::vector<uint64_t> compare3 = { 11, 22, 33, 44, 55, 66, 77, 88, 99 };
 
-      CHECK(test.tick_list.size() != 0);
+      CHECK(object.tick_list.size() != 0);
       CHECK(free_tick_list1.size() != 0);
       CHECK(free_tick_list2.size() != 0);
 
-      CHECK_ARRAY_EQUAL(compare1.data(), test.tick_list.data(),  compare1.size());
+      CHECK_ARRAY_EQUAL(compare1.data(), object.tick_list.data(),  compare1.size());
       CHECK_ARRAY_EQUAL(compare2.data(), free_tick_list1.data(), compare2.size());
       CHECK_ARRAY_EQUAL(compare3.data(), free_tick_list2.data(), compare3.size());
     }
@@ -262,11 +262,11 @@ namespace
     {
       etl::callback_timer<3> timer_controller;
 
-      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,        37, etl::timer::mode::REPEATING);
-      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback, 23, etl::timer::mode::REPEATING);
-      etl::timer::id::type id3 = timer_controller.register_timer(free_callback2,         11, etl::timer::mode::REPEATING);
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,        37, etl::timer::mode::Repeating);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback, 23, etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = timer_controller.register_timer(free_callback2,         11, etl::timer::mode::Repeating);
 
-      test.tick_list.clear();
+      object.tick_list.clear();
       free_tick_list1.clear();
       free_tick_list2.clear();
 
@@ -294,11 +294,11 @@ namespace
       std::vector<uint64_t> compare2 = { 25, 50, 70, 95 };
       std::vector<uint64_t> compare3 = { 15, 25, 35, 45, 55, 70, 80, 90, 100 };
 
-      CHECK(test.tick_list.size() != 0);
+      CHECK(object.tick_list.size() != 0);
       CHECK(free_tick_list1.size() != 0);
       CHECK(free_tick_list2.size() != 0);
 
-      CHECK_ARRAY_EQUAL(compare1.data(), test.tick_list.data(),  compare1.size());
+      CHECK_ARRAY_EQUAL(compare1.data(), object.tick_list.data(),  compare1.size());
       CHECK_ARRAY_EQUAL(compare2.data(), free_tick_list1.data(), compare2.size());
       CHECK_ARRAY_EQUAL(compare3.data(), free_tick_list2.data(), compare3.size());
     }
@@ -308,11 +308,11 @@ namespace
     {
       etl::callback_timer<3> timer_controller;
 
-      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,        37, etl::timer::mode::REPEATING);
-      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback, 23, etl::timer::mode::REPEATING);
-      etl::timer::id::type id3 = timer_controller.register_timer(free_callback2,         11, etl::timer::mode::REPEATING);
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,        37, etl::timer::mode::Repeating);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback, 23, etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = timer_controller.register_timer(free_callback2,         11, etl::timer::mode::Repeating);
 
-      test.tick_list.clear();
+      object.tick_list.clear();
       free_tick_list1.clear();
       free_tick_list2.clear();
 
@@ -347,11 +347,11 @@ namespace
       std::vector<uint64_t> compare2 = { 23 };
       std::vector<uint64_t> compare3 = { 11, 22, 33, 44, 55, 66, 77, 88, 99 };
 
-      CHECK(test.tick_list.size() != 0);
+      CHECK(object.tick_list.size() != 0);
       CHECK(free_tick_list1.size() != 0);
       CHECK(free_tick_list2.size() != 0);
 
-      CHECK_ARRAY_EQUAL(compare1.data(), test.tick_list.data(),  compare1.size());
+      CHECK_ARRAY_EQUAL(compare1.data(), object.tick_list.data(),  compare1.size());
       CHECK_ARRAY_EQUAL(compare2.data(), free_tick_list1.data(), compare2.size());
       CHECK_ARRAY_EQUAL(compare3.data(), free_tick_list2.data(), compare3.size());
     }
@@ -361,16 +361,16 @@ namespace
     {
       etl::callback_timer<3> timer_controller;
 
-      etl::timer::id::type id1 = timer_controller.register_timer(member_callback2, 100, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id2 = timer_controller.register_timer(member_callback, 10, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id3 = timer_controller.register_timer(member_callback, 22, etl::timer::mode::SINGLE_SHOT);
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback2, 100, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id2 = timer_controller.register_timer(member_callback, 10, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id3 = timer_controller.register_timer(member_callback, 22, etl::timer::mode::Single_Shot);
 
       (void)id2;
       (void)id3;
 
-      test.set_controller(timer_controller);
+      object.set_controller(timer_controller);
 
-      test.tick_list.clear();
+      object.tick_list.clear();
 
       timer_controller.start(id1);
 
@@ -388,9 +388,9 @@ namespace
 
       std::vector<uint64_t> compare1 = { 100, 110, 122 };
 
-      CHECK(test.tick_list.size() != 0);
+      CHECK(object.tick_list.size() != 0);
 
-      CHECK_ARRAY_EQUAL(compare1.data(), test.tick_list.data(), compare1.size());
+      CHECK_ARRAY_EQUAL(compare1.data(), object.tick_list.data(), compare1.size());
     }
 
     //*************************************************************************
@@ -398,16 +398,16 @@ namespace
     {
       etl::callback_timer<3> timer_controller;
 
-      etl::timer::id::type id1 = timer_controller.register_timer(member_callback2, 100, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id2 = timer_controller.register_timer(member_callback,   10, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id3 = timer_controller.register_timer(member_callback,   22, etl::timer::mode::SINGLE_SHOT);
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback2, 100, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id2 = timer_controller.register_timer(member_callback,   10, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id3 = timer_controller.register_timer(member_callback,   22, etl::timer::mode::Single_Shot);
 
       (void)id2;
       (void)id3;
 
-      test.set_controller(timer_controller);
+      object.set_controller(timer_controller);
 
-      test.tick_list.clear();
+      object.tick_list.clear();
 
       timer_controller.start(id1);
 
@@ -425,9 +425,9 @@ namespace
 
       std::vector<uint64_t> compare1 = { 102, 111, 123 };
 
-      CHECK(test.tick_list.size() != 0);
+      CHECK(object.tick_list.size() != 0);
 
-      CHECK_ARRAY_EQUAL(compare1.data(), test.tick_list.data(),  compare1.size());
+      CHECK_ARRAY_EQUAL(compare1.data(), object.tick_list.data(),  compare1.size());
     }
 
     //*************************************************************************
@@ -436,10 +436,10 @@ namespace
       etl::callback_timer<3> timer_controller;
 
       etl::timer::id::type id1;
-      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback, 23, etl::timer::mode::REPEATING);
-      etl::timer::id::type id3 = timer_controller.register_timer(free_callback2,         11, etl::timer::mode::REPEATING);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback, 23, etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = timer_controller.register_timer(free_callback2,         11, etl::timer::mode::Repeating);
 
-      test.tick_list.clear();
+      object.tick_list.clear();
       free_tick_list1.clear();
       free_tick_list2.clear();
 
@@ -458,7 +458,7 @@ namespace
         {
           timer_controller.unregister_timer(id2);
 
-          id1 = timer_controller.register_timer(member_callback, 37, etl::timer::mode::REPEATING);
+          id1 = timer_controller.register_timer(member_callback, 37, etl::timer::mode::Repeating);
           timer_controller.start(id1);
         }
 
@@ -470,11 +470,11 @@ namespace
       std::vector<uint64_t> compare2 = { 23 };
       std::vector<uint64_t> compare3 = { 11, 22, 33, 44, 55, 66, 77, 88, 99 };
 
-      CHECK(test.tick_list.size() != 0);
+      CHECK(object.tick_list.size() != 0);
       CHECK(free_tick_list1.size() != 0);
       CHECK(free_tick_list2.size() != 0);
 
-      CHECK_ARRAY_EQUAL(compare1.data(), test.tick_list.data(),  compare1.size());
+      CHECK_ARRAY_EQUAL(compare1.data(), object.tick_list.data(),  compare1.size());
       CHECK_ARRAY_EQUAL(compare2.data(), free_tick_list1.data(), compare2.size());
       CHECK_ARRAY_EQUAL(compare3.data(), free_tick_list2.data(), compare3.size());
     }
@@ -484,11 +484,11 @@ namespace
     {
       etl::callback_timer<3> timer_controller;
 
-      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,        37, etl::timer::mode::REPEATING);
-      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback, 23, etl::timer::mode::REPEATING);
-      etl::timer::id::type id3 = timer_controller.register_timer(free_callback2,         11, etl::timer::mode::REPEATING);
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,        37, etl::timer::mode::Repeating);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback, 23, etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = timer_controller.register_timer(free_callback2,         11, etl::timer::mode::Repeating);
 
-      test.tick_list.clear();
+      object.tick_list.clear();
       free_tick_list1.clear();
       free_tick_list2.clear();
 
@@ -518,11 +518,11 @@ namespace
       std::vector<uint64_t> compare2 = { 23 };
       std::vector<uint64_t> compare3 = { 11, 22, 33 };
 
-      CHECK(test.tick_list.size() != 0);
+      CHECK(object.tick_list.size() != 0);
       CHECK(free_tick_list1.size() != 0);
       CHECK(free_tick_list2.size() != 0);
 
-      CHECK_ARRAY_EQUAL(compare1.data(), test.tick_list.data(),  compare1.size());
+      CHECK_ARRAY_EQUAL(compare1.data(), object.tick_list.data(),  compare1.size());
       CHECK_ARRAY_EQUAL(compare2.data(), free_tick_list1.data(), compare2.size());
       CHECK_ARRAY_EQUAL(compare3.data(), free_tick_list2.data(), compare3.size());
     }
@@ -532,11 +532,11 @@ namespace
     {
       etl::callback_timer<3> timer_controller;
 
-      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,        37, etl::timer::mode::REPEATING);
-      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback, 23, etl::timer::mode::REPEATING);
-      etl::timer::id::type id3 = timer_controller.register_timer(free_callback2,         11, etl::timer::mode::REPEATING);
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,        37, etl::timer::mode::Repeating);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback, 23, etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = timer_controller.register_timer(free_callback2,         11, etl::timer::mode::Repeating);
 
-      test.tick_list.clear();
+      object.tick_list.clear();
       free_tick_list1.clear();
       free_tick_list2.clear();
 
@@ -545,9 +545,9 @@ namespace
       ticks = 5;
       timer_controller.tick(uint32_t(ticks));
 
-      timer_controller.start(id1, etl::timer::start::IMMEDIATE);
-      timer_controller.start(id2, etl::timer::start::IMMEDIATE);
-      timer_controller.start(id3, etl::timer::start::DELAYED);
+      timer_controller.start(id1, etl::timer::start::Immediate);
+      timer_controller.start(id2, etl::timer::start::Immediate);
+      timer_controller.start(id3, etl::timer::start::Delayed);
 
       const uint32_t step = 1U;
 
@@ -561,11 +561,11 @@ namespace
       std::vector<uint64_t> compare2 = { 6, 28, 51, 74, 97 };
       std::vector<uint64_t> compare3 = { 16, 27, 38, 49, 60, 71, 82, 93 };
 
-      CHECK(test.tick_list.size() != 0);
+      CHECK(object.tick_list.size() != 0);
       CHECK(free_tick_list1.size() != 0);
       CHECK(free_tick_list2.size() != 0);
 
-      CHECK_ARRAY_EQUAL(compare1.data(), test.tick_list.data(),  compare1.size());
+      CHECK_ARRAY_EQUAL(compare1.data(), object.tick_list.data(),  compare1.size());
       CHECK_ARRAY_EQUAL(compare2.data(), free_tick_list1.data(), compare2.size());
       CHECK_ARRAY_EQUAL(compare3.data(), free_tick_list2.data(), compare3.size());
     }
@@ -575,8 +575,8 @@ namespace
     {
       etl::callback_timer<3> timer_controller;
 
-      etl::timer::id::type id1 = timer_controller.register_timer(free_callback1, 15, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id2 = timer_controller.register_timer(free_callback2, 5,  etl::timer::mode::REPEATING);
+      etl::timer::id::type id1 = timer_controller.register_timer(free_callback1, 15, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_callback2, 5,  etl::timer::mode::Repeating);
 
       free_tick_list1.clear();
       free_tick_list2.clear();
@@ -611,7 +611,7 @@ namespace
     {
       etl::callback_timer<3> timer_controller;
 
-      etl::timer::id::type id1 = timer_controller.register_timer(free_callback1, 5, etl::timer::mode::SINGLE_SHOT);
+      etl::timer::id::type id1 = timer_controller.register_timer(free_callback1, 5, etl::timer::mode::Single_Shot);
 
       free_tick_list1.clear();
 
@@ -646,6 +646,86 @@ namespace
       CHECK_ARRAY_EQUAL(compare1.data(), free_tick_list1.data(), compare1.size());
     }
 
+    //*************************************************************************
+    TEST(message_timer_time_to_next_repeating)
+    {
+      etl::callback_timer<3> timer_controller;
+
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,        37, etl::timer::mode::Repeating);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback, 23, etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = timer_controller.register_timer(free_callback2,         11, etl::timer::mode::Repeating);
+
+      timer_controller.start(id1);
+      timer_controller.start(id3);
+      timer_controller.start(id2);
+
+      timer_controller.enable(true);
+
+      CHECK_EQUAL(11, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(4, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(8, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(1, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(5, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(2, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(2, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(6, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(10, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(3, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(4, timer_controller.time_to_next());
+    }
+
+    //*************************************************************************
+    TEST(message_timer_time_to_next_with_has_active_timer)
+    {
+      etl::callback_timer<3> timer_controller;
+
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback, 37, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback, 23, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id3 = timer_controller.register_timer(free_callback2, 11, etl::timer::mode::Single_Shot);
+
+      timer_controller.start(id1);
+      timer_controller.start(id3);
+      timer_controller.start(id2);
+
+      timer_controller.enable(true);
+
+      timer_controller.tick(11);
+      CHECK_EQUAL(12, timer_controller.time_to_next());
+      CHECK_TRUE(timer_controller.has_active_timer());
+
+      timer_controller.tick(23);
+      CHECK_EQUAL(3, timer_controller.time_to_next());
+      CHECK_TRUE(timer_controller.has_active_timer());
+
+      timer_controller.tick(2);
+      CHECK_EQUAL(1, timer_controller.time_to_next());
+      CHECK_TRUE(timer_controller.has_active_timer());
+
+      timer_controller.tick(1);
+      CHECK_EQUAL(static_cast<etl::timer::interval::type>(etl::timer::interval::No_Active_Interval), timer_controller.time_to_next());
+      CHECK_FALSE(timer_controller.has_active_timer());
+    }
+
     //*************************************************************************
     class test_object
     {
@@ -669,7 +749,7 @@ namespace
 
         timer_controller.enable(true);
 
-        etl::timer::id::type id = timer_controller.register_timer(delegate_callback, 5, etl::timer::mode::SINGLE_SHOT);
+        etl::timer::id::type id = timer_controller.register_timer(delegate_callback, 5, etl::timer::mode::Single_Shot);
         timer_controller.start(id);
 
         timer_controller.tick(4);
@@ -679,6 +759,41 @@ namespace
         CHECK(test_obj.called == 1);
     }
 
+    //*************************************************************************
+    TEST(callback_timer_is_active)
+    {
+      etl::callback_timer<4> timer_controller;
+
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,        37, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback, 23, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id3 = timer_controller.register_timer(free_callback2,         11, etl::timer::mode::Single_Shot);
+
+      timer_controller.start(id1);
+      timer_controller.start(id3);
+      timer_controller.start(id2);
+
+      timer_controller.enable(true);
+
+      CHECK_TRUE(timer_controller.is_active(id1));
+      CHECK_TRUE(timer_controller.is_active(id2));
+      CHECK_TRUE(timer_controller.is_active(id3));
+
+      timer_controller.tick(11);
+      CHECK_TRUE(timer_controller.is_active(id1));
+      CHECK_TRUE(timer_controller.is_active(id2));
+      CHECK_FALSE(timer_controller.is_active(id3));
+
+      timer_controller.tick(23 - 11);
+      CHECK_TRUE(timer_controller.is_active(id1));
+      CHECK_FALSE(timer_controller.is_active(id2));
+      CHECK_FALSE(timer_controller.is_active(id3));
+
+      timer_controller.tick(37 - 23);
+      CHECK_FALSE(timer_controller.is_active(id1));
+      CHECK_FALSE(timer_controller.is_active(id2));
+      CHECK_FALSE(timer_controller.is_active(id3));
+    }
+
     //*************************************************************************
 #if REALTIME_TEST
 
@@ -722,11 +837,11 @@ namespace
     {
       FIX_PROCESSOR_AFFINITY;
 
-      etl::timer::id::type id1 = controller.register_timer(member_callback,        400, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id2 = controller.register_timer(free_function_callback, 100, etl::timer::mode::REPEATING);
-      etl::timer::id::type id3 = controller.register_timer(free_callback2,          10, etl::timer::mode::REPEATING);
+      etl::timer::id::type id1 = controller.register_timer(member_callback,        400, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id2 = controller.register_timer(free_function_callback, 100, etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = controller.register_timer(free_callback2,          10, etl::timer::mode::Repeating);
 
-      test.tick_list.clear();
+      object.tick_list.clear();
       free_tick_list1.clear();
       free_tick_list2.clear();
 
@@ -764,18 +879,18 @@ namespace
       //Join the thread with the main thread
       t1.join();
 
-      CHECK_EQUAL(2U,  test.tick_list.size());
+      CHECK_EQUAL(2U,  object.tick_list.size());
       CHECK_EQUAL(10U, free_tick_list1.size());
       CHECK(free_tick_list2.size() < 65U);
 
       //std::vector<uint64_t> compare1 = { 400, 900 };
       //std::vector<uint64_t> compare2 = { 100, 200, 300, 400, 500, 600, 700, 800, 900, 1000 };
 
-      CHECK(test.tick_list.size()  != 0);
+      CHECK(object.tick_list.size()  != 0);
       CHECK(free_tick_list1.size() != 0);
       CHECK(free_tick_list2.size() != 0);
 
-      //CHECK_ARRAY_EQUAL(compare1.data(), test.tick_list.data(),  min(compare1.size(), test.tick_list.size()));
+      //CHECK_ARRAY_EQUAL(compare1.data(), object.tick_list.data(),  min(compare1.size(), object.tick_list.size()));
       //CHECK_ARRAY_EQUAL(compare2.data(), free_tick_list1.data(), min(compare2.size(), free_tick_list1.size()));
     }
 #endif
