@@ -84,11 +84,11 @@ namespace
   //***************************************************************************
   // Class callback via etl::function
   //***************************************************************************
-  class Test
+  class Object
   {
   public:
 
-    Test()
+    Object()
       : p_controller(nullptr)
     {
     }
@@ -121,9 +121,9 @@ namespace
   using lock_type     = etl::icallback_timer_locked::lock_type;
   using unlock_type   = etl::icallback_timer_locked::unlock_type;
 
-  Test test;
-  callback_type member_callback  = callback_type::create<Test, test, &Test::callback>();
-  callback_type member_callback2 = callback_type::create<Test, test, &Test::callback2>();
+  Object object;
+  callback_type member_callback  = callback_type::create<Object, object, &Object::callback>();
+  callback_type member_callback2 = callback_type::create<Object, object, &Object::callback2>();
 
   //***************************************************************************
   // Free function callback via etl::function
@@ -161,16 +161,16 @@ namespace
 
       etl::callback_timer_locked<2> timer_controller(try_lock, lock, unlock);
 
-      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,         37, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback,  23, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id3 = timer_controller.register_timer(free_function_callback2, 11, etl::timer::mode::SINGLE_SHOT);
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,         37, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback,  23, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id3 = timer_controller.register_timer(free_function_callback2, 11, etl::timer::mode::Single_Shot);
 
       CHECK(id1 != etl::timer::id::NO_TIMER);
       CHECK(id2 != etl::timer::id::NO_TIMER);
       CHECK(id3 == etl::timer::id::NO_TIMER);
 
       timer_controller.clear();
-      id3 = timer_controller.register_timer(free_function_callback2, 11, etl::timer::mode::SINGLE_SHOT);
+      id3 = timer_controller.register_timer(free_function_callback2, 11, etl::timer::mode::Single_Shot);
       CHECK(id3 != etl::timer::id::NO_TIMER);
 
       CHECK_EQUAL(0U, locks.lock_count);
@@ -186,11 +186,11 @@ namespace
 
       etl::callback_timer_locked<4> timer_controller(try_lock, lock, unlock);
 
-      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,         37, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback,  23, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id3 = timer_controller.register_timer(free_function_callback2, 11, etl::timer::mode::SINGLE_SHOT);
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,         37, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback,  23, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id3 = timer_controller.register_timer(free_function_callback2, 11, etl::timer::mode::Single_Shot);
 
-      test.tick_list.clear();
+      object.tick_list.clear();
       free_tick_list1.clear();
       free_tick_list2.clear();
 
@@ -214,11 +214,11 @@ namespace
       std::vector<uint64_t> compare2 = { 23 };
       std::vector<uint64_t> compare3 = { 11 };
 
-      CHECK(test.tick_list.size() != 0);
+      CHECK(object.tick_list.size() != 0);
       CHECK(free_tick_list1.size() != 0);
       CHECK(free_tick_list2.size() != 0);
 
-      CHECK_ARRAY_EQUAL(compare1.data(), test.tick_list.data(),  compare1.size());
+      CHECK_ARRAY_EQUAL(compare1.data(), object.tick_list.data(),  compare1.size());
       CHECK_ARRAY_EQUAL(compare2.data(), free_tick_list1.data(), compare2.size());
       CHECK_ARRAY_EQUAL(compare3.data(), free_tick_list2.data(), compare3.size());
 
@@ -235,8 +235,8 @@ namespace
 
       etl::callback_timer_locked<1> timer_controller(try_lock, lock, unlock);
 
-      etl::timer::id::type id1 = timer_controller.register_timer(member_callback, 37, etl::timer::mode::SINGLE_SHOT);
-      test.tick_list.clear();
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback, 37, etl::timer::mode::Single_Shot);
+      object.tick_list.clear();
 
       timer_controller.start(id1);
       timer_controller.enable(true);
@@ -256,7 +256,7 @@ namespace
       CHECK(timer_controller.set_period(id1, 50));
       timer_controller.start(id1);
 
-      test.tick_list.clear();
+      object.tick_list.clear();
 
       ticks = 0;
 
@@ -268,7 +268,7 @@ namespace
 
       // Timer should have timed out.
 
-      CHECK_EQUAL(50U, *test.tick_list.data());
+      CHECK_EQUAL(50U, *object.tick_list.data());
 
       CHECK(timer_controller.unregister_timer(id1));
       CHECK(!timer_controller.unregister_timer(id1));
@@ -288,11 +288,11 @@ namespace
 
       etl::callback_timer_locked<3> timer_controller(try_lock, lock, unlock);
 
-      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,         37, etl::timer::mode::REPEATING);
-      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback,  23, etl::timer::mode::REPEATING);
-      etl::timer::id::type id3 = timer_controller.register_timer(free_function_callback2, 11, etl::timer::mode::REPEATING);
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,         37, etl::timer::mode::Repeating);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback,  23, etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = timer_controller.register_timer(free_function_callback2, 11, etl::timer::mode::Repeating);
 
-      test.tick_list.clear();
+      object.tick_list.clear();
       free_tick_list1.clear();
       free_tick_list2.clear();
 
@@ -316,11 +316,11 @@ namespace
       std::vector<uint64_t> compare2 = { 23, 46, 69, 92 };
       std::vector<uint64_t> compare3 = { 11, 22, 33, 44, 55, 66, 77, 88, 99 };
 
-      CHECK(test.tick_list.size() != 0);
+      CHECK(object.tick_list.size() != 0);
       CHECK(free_tick_list1.size() != 0);
       CHECK(free_tick_list2.size() != 0);
 
-      CHECK_ARRAY_EQUAL(compare1.data(), test.tick_list.data(),  compare1.size());
+      CHECK_ARRAY_EQUAL(compare1.data(), object.tick_list.data(),  compare1.size());
       CHECK_ARRAY_EQUAL(compare2.data(), free_tick_list1.data(), compare2.size());
       CHECK_ARRAY_EQUAL(compare3.data(), free_tick_list2.data(), compare3.size());
 
@@ -337,11 +337,11 @@ namespace
 
       etl::callback_timer_locked<3> timer_controller(try_lock, lock, unlock);
 
-      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,         37, etl::timer::mode::REPEATING);
-      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback,  23, etl::timer::mode::REPEATING);
-      etl::timer::id::type id3 = timer_controller.register_timer(free_function_callback2, 11, etl::timer::mode::REPEATING);
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,         37, etl::timer::mode::Repeating);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback,  23, etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = timer_controller.register_timer(free_function_callback2, 11, etl::timer::mode::Repeating);
 
-      test.tick_list.clear();
+      object.tick_list.clear();
       free_tick_list1.clear();
       free_tick_list2.clear();
 
@@ -369,11 +369,11 @@ namespace
       std::vector<uint64_t> compare2 = { 25, 50, 70, 95 };
       std::vector<uint64_t> compare3 = { 15, 25, 35, 45, 55, 70, 80, 90, 100 };
 
-      CHECK(test.tick_list.size() != 0);
+      CHECK(object.tick_list.size() != 0);
       CHECK(free_tick_list1.size() != 0);
       CHECK(free_tick_list2.size() != 0);
 
-      CHECK_ARRAY_EQUAL(compare1.data(), test.tick_list.data(),  compare1.size());
+      CHECK_ARRAY_EQUAL(compare1.data(), object.tick_list.data(),  compare1.size());
       CHECK_ARRAY_EQUAL(compare2.data(), free_tick_list1.data(), compare2.size());
       CHECK_ARRAY_EQUAL(compare3.data(), free_tick_list2.data(), compare3.size());
 
@@ -390,11 +390,11 @@ namespace
 
       etl::callback_timer_locked<3> timer_controller(try_lock, lock, unlock);
 
-      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,         37, etl::timer::mode::REPEATING);
-      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback,  23, etl::timer::mode::REPEATING);
-      etl::timer::id::type id3 = timer_controller.register_timer(free_function_callback2, 11, etl::timer::mode::REPEATING);
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,         37, etl::timer::mode::Repeating);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback,  23, etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = timer_controller.register_timer(free_function_callback2, 11, etl::timer::mode::Repeating);
 
-      test.tick_list.clear();
+      object.tick_list.clear();
       free_tick_list1.clear();
       free_tick_list2.clear();
 
@@ -429,11 +429,11 @@ namespace
       std::vector<uint64_t> compare2 = { 23 };
       std::vector<uint64_t> compare3 = { 11, 22, 33, 44, 55, 66, 77, 88, 99 };
 
-      CHECK(test.tick_list.size() != 0);
+      CHECK(object.tick_list.size() != 0);
       CHECK(free_tick_list1.size() != 0);
       CHECK(free_tick_list2.size() != 0);
 
-      CHECK_ARRAY_EQUAL(compare1.data(), test.tick_list.data(),  compare1.size());
+      CHECK_ARRAY_EQUAL(compare1.data(), object.tick_list.data(),  compare1.size());
       CHECK_ARRAY_EQUAL(compare2.data(), free_tick_list1.data(), compare2.size());
       CHECK_ARRAY_EQUAL(compare3.data(), free_tick_list2.data(), compare3.size());
 
@@ -450,16 +450,16 @@ namespace
 
       etl::callback_timer_locked<3> timer_controller(try_lock, lock, unlock);
 
-      etl::timer::id::type id1 = timer_controller.register_timer(member_callback2, 100, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id2 = timer_controller.register_timer(member_callback, 10, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id3 = timer_controller.register_timer(member_callback, 22, etl::timer::mode::SINGLE_SHOT);
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback2, 100, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id2 = timer_controller.register_timer(member_callback, 10, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id3 = timer_controller.register_timer(member_callback, 22, etl::timer::mode::Single_Shot);
 
       (void)id2;
       (void)id3;
 
-      test.set_controller(timer_controller);
+      object.set_controller(timer_controller);
 
-      test.tick_list.clear();
+      object.tick_list.clear();
 
       timer_controller.start(id1);
 
@@ -477,9 +477,9 @@ namespace
 
       std::vector<uint64_t> compare1 = { 100, 110, 122 };
 
-      CHECK(test.tick_list.size() != 0);
+      CHECK(object.tick_list.size() != 0);
 
-      CHECK_ARRAY_EQUAL(compare1.data(), test.tick_list.data(), compare1.size());
+      CHECK_ARRAY_EQUAL(compare1.data(), object.tick_list.data(), compare1.size());
 
       CHECK_EQUAL(0U, locks.lock_count);
     }
@@ -494,16 +494,16 @@ namespace
 
       etl::callback_timer_locked<3> timer_controller(try_lock, lock, unlock);
 
-      etl::timer::id::type id1 = timer_controller.register_timer(member_callback2, 100, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id2 = timer_controller.register_timer(member_callback,   10, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id3 = timer_controller.register_timer(member_callback,   22, etl::timer::mode::SINGLE_SHOT);
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback2, 100, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id2 = timer_controller.register_timer(member_callback,   10, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id3 = timer_controller.register_timer(member_callback,   22, etl::timer::mode::Single_Shot);
 
       (void)id2;
       (void)id3;
 
-      test.set_controller(timer_controller);
+      object.set_controller(timer_controller);
 
-      test.tick_list.clear();
+      object.tick_list.clear();
 
       timer_controller.start(id1);
 
@@ -521,9 +521,9 @@ namespace
 
       std::vector<uint64_t> compare1 = { 102, 111, 123 };
 
-      CHECK(test.tick_list.size() != 0);
+      CHECK(object.tick_list.size() != 0);
 
-      CHECK_ARRAY_EQUAL(compare1.data(), test.tick_list.data(),  compare1.size());
+      CHECK_ARRAY_EQUAL(compare1.data(), object.tick_list.data(),  compare1.size());
 
       CHECK_EQUAL(0U, locks.lock_count);
     }
@@ -539,10 +539,10 @@ namespace
       etl::callback_timer_locked<3> timer_controller(try_lock, lock, unlock);
 
       etl::timer::id::type id1;
-      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback,  23, etl::timer::mode::REPEATING);
-      etl::timer::id::type id3 = timer_controller.register_timer(free_function_callback2, 11, etl::timer::mode::REPEATING);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback,  23, etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = timer_controller.register_timer(free_function_callback2, 11, etl::timer::mode::Repeating);
 
-      test.tick_list.clear();
+      object.tick_list.clear();
       free_tick_list1.clear();
       free_tick_list2.clear();
 
@@ -561,7 +561,7 @@ namespace
         {
           timer_controller.unregister_timer(id2);
 
-          id1 = timer_controller.register_timer(member_callback, 37, etl::timer::mode::REPEATING);
+          id1 = timer_controller.register_timer(member_callback, 37, etl::timer::mode::Repeating);
           timer_controller.start(id1);
         }
 
@@ -573,11 +573,11 @@ namespace
       std::vector<uint64_t> compare2 = { 23 };
       std::vector<uint64_t> compare3 = { 11, 22, 33, 44, 55, 66, 77, 88, 99 };
 
-      CHECK(test.tick_list.size() != 0);
+      CHECK(object.tick_list.size() != 0);
       CHECK(free_tick_list1.size() != 0);
       CHECK(free_tick_list2.size() != 0);
 
-      CHECK_ARRAY_EQUAL(compare1.data(), test.tick_list.data(),  compare1.size());
+      CHECK_ARRAY_EQUAL(compare1.data(), object.tick_list.data(),  compare1.size());
       CHECK_ARRAY_EQUAL(compare2.data(), free_tick_list1.data(), compare2.size());
       CHECK_ARRAY_EQUAL(compare3.data(), free_tick_list2.data(), compare3.size());
 
@@ -594,11 +594,11 @@ namespace
 
       etl::callback_timer_locked<3> timer_controller(try_lock, lock, unlock);
 
-      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,         37, etl::timer::mode::REPEATING);
-      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback,  23, etl::timer::mode::REPEATING);
-      etl::timer::id::type id3 = timer_controller.register_timer(free_function_callback2, 11, etl::timer::mode::REPEATING);
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,         37, etl::timer::mode::Repeating);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback,  23, etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = timer_controller.register_timer(free_function_callback2, 11, etl::timer::mode::Repeating);
 
-      test.tick_list.clear();
+      object.tick_list.clear();
       free_tick_list1.clear();
       free_tick_list2.clear();
 
@@ -628,11 +628,11 @@ namespace
       std::vector<uint64_t> compare2 = { 23 };
       std::vector<uint64_t> compare3 = { 11, 22, 33 };
 
-      CHECK(test.tick_list.size() != 0);
+      CHECK(object.tick_list.size() != 0);
       CHECK(free_tick_list1.size() != 0);
       CHECK(free_tick_list2.size() != 0);
 
-      CHECK_ARRAY_EQUAL(compare1.data(), test.tick_list.data(),  compare1.size());
+      CHECK_ARRAY_EQUAL(compare1.data(), object.tick_list.data(),  compare1.size());
       CHECK_ARRAY_EQUAL(compare2.data(), free_tick_list1.data(), compare2.size());
       CHECK_ARRAY_EQUAL(compare3.data(), free_tick_list2.data(), compare3.size());
 
@@ -649,11 +649,11 @@ namespace
 
       etl::callback_timer_locked<3> timer_controller(try_lock, lock, unlock);
 
-      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,         37, etl::timer::mode::REPEATING);
-      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback,  23, etl::timer::mode::REPEATING);
-      etl::timer::id::type id3 = timer_controller.register_timer(free_function_callback2, 11, etl::timer::mode::REPEATING);
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,         37, etl::timer::mode::Repeating);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback,  23, etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = timer_controller.register_timer(free_function_callback2, 11, etl::timer::mode::Repeating);
 
-      test.tick_list.clear();
+      object.tick_list.clear();
       free_tick_list1.clear();
       free_tick_list2.clear();
 
@@ -662,9 +662,9 @@ namespace
       ticks = 5;
       timer_controller.tick(uint32_t(ticks));
 
-      timer_controller.start(id1, etl::timer::start::IMMEDIATE);
-      timer_controller.start(id2, etl::timer::start::IMMEDIATE);
-      timer_controller.start(id3, etl::timer::start::DELAYED);
+      timer_controller.start(id1, etl::timer::start::Immediate);
+      timer_controller.start(id2, etl::timer::start::Immediate);
+      timer_controller.start(id3, etl::timer::start::Delayed);
 
       const uint32_t step = 1U;
 
@@ -678,11 +678,11 @@ namespace
       std::vector<uint64_t> compare2 = { 6, 28, 51, 74, 97 };
       std::vector<uint64_t> compare3 = { 16, 27, 38, 49, 60, 71, 82, 93 };
 
-      CHECK(test.tick_list.size() != 0);
+      CHECK(object.tick_list.size() != 0);
       CHECK(free_tick_list1.size() != 0);
       CHECK(free_tick_list2.size() != 0);
 
-      CHECK_ARRAY_EQUAL(compare1.data(), test.tick_list.data(),  compare1.size());
+      CHECK_ARRAY_EQUAL(compare1.data(), object.tick_list.data(),  compare1.size());
       CHECK_ARRAY_EQUAL(compare2.data(), free_tick_list1.data(), compare2.size());
       CHECK_ARRAY_EQUAL(compare3.data(), free_tick_list2.data(), compare3.size());
 
@@ -699,8 +699,8 @@ namespace
 
       etl::callback_timer_locked<3> timer_controller(try_lock, lock, unlock);
 
-      etl::timer::id::type id1 = timer_controller.register_timer(free_function_callback,  15, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback2, 5,  etl::timer::mode::REPEATING);
+      etl::timer::id::type id1 = timer_controller.register_timer(free_function_callback,  15, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback2, 5,  etl::timer::mode::Repeating);
 
       free_tick_list1.clear();
       free_tick_list2.clear();
@@ -742,7 +742,7 @@ namespace
 
       etl::callback_timer_locked<3> timer_controller(try_lock, lock, unlock);
 
-      etl::timer::id::type id1 = timer_controller.register_timer(free_function_callback, 5, etl::timer::mode::SINGLE_SHOT);
+      etl::timer::id::type id1 = timer_controller.register_timer(free_function_callback, 5, etl::timer::mode::Single_Shot);
 
       free_tick_list1.clear();
 
@@ -806,7 +806,7 @@ namespace
 
         timer_controller.enable(true);
 
-        etl::timer::id::type id = timer_controller.register_timer(delegate_callback, 5, etl::timer::mode::SINGLE_SHOT);
+        etl::timer::id::type id = timer_controller.register_timer(delegate_callback, 5, etl::timer::mode::Single_Shot);
         timer_controller.start(id);
 
         timer_controller.tick(4);
@@ -818,6 +818,136 @@ namespace
         CHECK_EQUAL(0U, locks.lock_count);
     }
 
+    //*************************************************************************
+    TEST(message_timer_time_to_next)
+    {
+      locks.clear();
+      try_lock_type try_lock = try_lock_type::create<Locks, locks, &Locks::try_lock>();
+      lock_type     lock     = lock_type::create<Locks, locks, &Locks::lock>();
+      unlock_type   unlock   = unlock_type::create<Locks, locks, &Locks::unlock>();
+
+      etl::callback_timer_locked<3> timer_controller(try_lock, lock, unlock);
+
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,         37, etl::timer::mode::Repeating);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback,  23, etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = timer_controller.register_timer(free_function_callback2, 11, etl::timer::mode::Repeating);
+
+      timer_controller.start(id1);
+      timer_controller.start(id3);
+      timer_controller.start(id2);
+
+      timer_controller.enable(true);
+
+      CHECK_EQUAL(11, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(4, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(8, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(1, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(5, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(2, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(2, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(6, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(10, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(3, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(4, timer_controller.time_to_next());
+    }
+
+    //*************************************************************************
+    TEST(callback_timer_is_active)
+    {
+      locks.clear();
+      try_lock_type try_lock = try_lock_type::create<Locks, locks, &Locks::try_lock>();
+      lock_type     lock     = lock_type::create<Locks, locks, &Locks::lock>();
+      unlock_type   unlock   = unlock_type::create<Locks, locks, &Locks::unlock>();
+
+      etl::callback_timer_locked<3> timer_controller(try_lock, lock, unlock);
+
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback,         37, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback,  23, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id3 = timer_controller.register_timer(free_function_callback2, 11, etl::timer::mode::Single_Shot);
+
+      timer_controller.start(id1);
+      timer_controller.start(id3);
+      timer_controller.start(id2);
+
+      timer_controller.enable(true);
+
+      CHECK_TRUE(timer_controller.is_active(id1));
+      CHECK_TRUE(timer_controller.is_active(id2));
+      CHECK_TRUE(timer_controller.is_active(id3));
+
+      timer_controller.tick(11);
+      CHECK_TRUE(timer_controller.is_active(id1));
+      CHECK_TRUE(timer_controller.is_active(id2));
+      CHECK_FALSE(timer_controller.is_active(id3));
+
+      timer_controller.tick(23 - 11);
+      CHECK_TRUE(timer_controller.is_active(id1));
+      CHECK_FALSE(timer_controller.is_active(id2));
+      CHECK_FALSE(timer_controller.is_active(id3));
+
+      timer_controller.tick(37 - 23);
+      CHECK_FALSE(timer_controller.is_active(id1));
+      CHECK_FALSE(timer_controller.is_active(id2));
+      CHECK_FALSE(timer_controller.is_active(id3));
+    }
+
+    //*************************************************************************
+    TEST(message_timer_time_to_next_with_has_active_timer)
+    {
+      locks.clear();
+      try_lock_type try_lock = try_lock_type::create<Locks, locks, &Locks::try_lock>();
+      lock_type     lock     = lock_type::create<Locks, locks, &Locks::lock>();
+      unlock_type   unlock   = unlock_type::create<Locks, locks, &Locks::unlock>();
+
+      etl::callback_timer_locked<3> timer_controller(try_lock, lock, unlock);
+
+      etl::timer::id::type id1 = timer_controller.register_timer(member_callback, 37, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id2 = timer_controller.register_timer(free_function_callback, 23, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id3 = timer_controller.register_timer(free_function_callback2, 11, etl::timer::mode::Single_Shot);
+
+      timer_controller.start(id1);
+      timer_controller.start(id3);
+      timer_controller.start(id2);
+
+      timer_controller.enable(true);
+
+      timer_controller.tick(11);
+      CHECK_EQUAL(12, timer_controller.time_to_next());
+      CHECK_TRUE(timer_controller.has_active_timer());
+
+      timer_controller.tick(23);
+      CHECK_EQUAL(3, timer_controller.time_to_next());
+      CHECK_TRUE(timer_controller.has_active_timer());
+
+      timer_controller.tick(2);
+      CHECK_EQUAL(1, timer_controller.time_to_next());
+      CHECK_TRUE(timer_controller.has_active_timer());
+
+      timer_controller.tick(1);
+      CHECK_EQUAL(static_cast<etl::timer::interval::type>(etl::timer::interval::No_Active_Interval), timer_controller.time_to_next());
+      CHECK_FALSE(timer_controller.has_active_timer());
+    }
+
     //*************************************************************************
 #if REALTIME_TEST
 
@@ -900,11 +1030,11 @@ namespace
     {
       FIX_PROCESSOR_AFFINITY;
 
-      etl::timer::id::type id1 = controller.register_timer(member_callback,         400, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id2 = controller.register_timer(free_function_callback,  100, etl::timer::mode::REPEATING);
-      etl::timer::id::type id3 = controller.register_timer(free_function_callback2,  10, etl::timer::mode::REPEATING);
+      etl::timer::id::type id1 = controller.register_timer(member_callback,         400, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id2 = controller.register_timer(free_function_callback,  100, etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = controller.register_timer(free_function_callback2,  10, etl::timer::mode::Repeating);
 
-      test.tick_list.clear();
+      object.tick_list.clear();
       free_tick_list1.clear();
       free_tick_list2.clear();
 
@@ -948,18 +1078,18 @@ namespace
       //Join the thread with the main thread
       t1.join();
 
-      CHECK_EQUAL(2U,  test.tick_list.size());
+      CHECK_EQUAL(2U,  object.tick_list.size());
       CHECK_EQUAL(10U, free_tick_list1.size());
       CHECK(free_tick_list2.size() < 65U);
 
       std::vector<uint64_t> compare1 = { 400, 900 };
       std::vector<uint64_t> compare2 = { 100, 200, 300, 400, 500, 600, 700, 800, 900, 1000 };
 
-      CHECK(test.tick_list.size()  != 0);
+      CHECK(object.tick_list.size()  != 0);
       CHECK(free_tick_list1.size() != 0);
       CHECK(free_tick_list2.size() != 0);
 
-      CHECK_ARRAY_EQUAL(compare1.data(), test.tick_list.data(),  min(compare1.size(), test.tick_list.size()));
+      CHECK_ARRAY_EQUAL(compare1.data(), object.tick_list.data(),  min(compare1.size(), object.tick_list.size()));
       CHECK_ARRAY_EQUAL(compare2.data(), free_tick_list1.data(), min(compare2.size(), free_tick_list1.size()));
 
       CHECK_EQUAL(0U, threadLock.lock_count);
