@@ -288,6 +288,14 @@ namespace
       CHECK(pool.max_size() == 4U);
     }
 
+    //*************************************************************************
+    TEST(test_max_item_size)
+    {
+      etl::pool<Test_Data, 4> pool;
+
+      CHECK(pool.max_item_size() == sizeof(Test_Data));
+    }
+
     //*************************************************************************
     TEST(test_size)
     {
