@@ -52,6 +52,7 @@ namespace
     typedef etl::span<int, 10U> View;
     typedef etl::span<int, 9U> SView;
     typedef etl::span<const int, 10U> CView;
+    typedef etl::span<int, 0U> EView;
 
 #if ETL_USING_CPP20
     using StdView = std::span<int, 10U>;
@@ -397,15 +398,19 @@ namespace
       View  view(etldata.begin(), etldata.end());
       CView cview(etldata.begin(), etldata.end());
 
+      CHECK_EQUAL(etldata.cbegin(), view.cbegin());
       CHECK_EQUAL(etldata.begin(), view.begin());
       CHECK_EQUAL(etldata.begin(), cview.begin());
 
+      CHECK_EQUAL(etldata.cend(), view.crbegin().base());
       CHECK_EQUAL(etldata.end(), view.rbegin().base());
       CHECK_EQUAL(etldata.end(), cview.rbegin().base());
 
+      CHECK_EQUAL(etldata.cend(), view.cend());
       CHECK_EQUAL(etldata.end(), view.end());
       CHECK_EQUAL(etldata.end(), cview.end());
 
+      CHECK_EQUAL(etldata.cbegin(), view.crend().base());
       CHECK_EQUAL(etldata.begin(), view.rend().base());
       CHECK_EQUAL(etldata.begin(), cview.rend().base());
     }
@@ -433,6 +438,22 @@ namespace
       CHECK_EQUAL(etldata.data(), cview.data());
     }
 
+    //*************************************************************************
+    TEST(test_at)
+    {
+      View  view(etldata.begin(), etldata.end());
+      CView cview(etldata.begin(), etldata.end());
+
+      for (size_t i = 0UL; i < etldata.size(); ++i)
+      {
+        CHECK_EQUAL(etldata.at(i), view.at(i));
+        CHECK_EQUAL(etldata.at(i), cview.at(i));
+      }
+
+      CHECK_THROW({ int d = view.at(view.size()); (void)d; }, etl::array_out_of_range);
+      CHECK_THROW({ int d = cview.at(cview.size()); (void)d; }, etl::array_out_of_range);
+    }
+
     //*************************************************************************
     TEST(test_index_operator)
     {
@@ -464,6 +485,9 @@ namespace
     {
       View view1(etldata.begin(), etldata.begin());
       CHECK(!view1.empty());
+
+      EView view2(etldata.begin(), etldata.begin());
+      CHECK(view2.empty());
     }
 
     //*************************************************************************
@@ -1123,6 +1147,25 @@ namespace
       }
     }
 
+    //*************************************************************************
+    TEST(test_make_span_c_array)
+    {
+      {
+        auto s = etl::make_span(cdata);
+
+        CHECK_EQUAL(s.size(), 10);
+        View view(etldata);
+        CHECK_TRUE(etl::equal(s, view));
+      }
+      {
+        auto s = etl::make_span(ccdata);
+
+        CHECK_EQUAL(s.size(), 10);
+        View view(etldata);
+        CHECK_TRUE(etl::equal(s, view));
+      }
+    }
+
 #include "etl/private/diagnostic_pop.h"
   };
 }
