@@ -58,15 +58,15 @@ namespace
       CHECK(etl::u32string<20>(STR("2147483648")) ==           etl::to_string(uint32_t(2147483648ul), str));
       CHECK(etl::u32string<20>(STR("9223372036854775808")) ==  etl::to_string(uint64_t(9223372036854775808ull), str));
 
-      CHECK(etl::u32string<20>(STR("127")) ==                  etl::to_string(int8_t(INT8_MAX), str));
-      CHECK(etl::u32string<20>(STR("32767")) ==                etl::to_string(int16_t(INT16_MAX), str));
-      CHECK(etl::u32string<20>(STR("2147483647")) ==           etl::to_string(int32_t(INT32_MAX), str));
-      CHECK(etl::u32string<20>(STR("9223372036854775807")) ==  etl::to_string(int64_t(INT64_MAX), str));
+      CHECK(etl::u32string<20>(STR("127")) ==                  etl::to_string(INT8_MAX, str));
+      CHECK(etl::u32string<20>(STR("32767")) ==                etl::to_string(INT16_MAX, str));
+      CHECK(etl::u32string<20>(STR("2147483647")) ==           etl::to_string(INT32_MAX, str));
+      CHECK(etl::u32string<20>(STR("9223372036854775807")) ==  etl::to_string(INT64_MAX, str));
 
-      CHECK(etl::u32string<20>(STR("-128")) ==                 etl::to_string(int8_t(INT8_MIN), str));
-      CHECK(etl::u32string<20>(STR("-32768")) ==               etl::to_string(int16_t(INT16_MIN), str));
-      CHECK(etl::u32string<20>(STR("-2147483648")) ==          etl::to_string(int32_t(INT32_MIN), str));
-      CHECK(etl::u32string<20>(STR("-9223372036854775808")) == etl::to_string(int64_t(INT64_MIN), str));
+      CHECK(etl::u32string<20>(STR("-128")) ==                 etl::to_string(INT8_MIN, str));
+      CHECK(etl::u32string<20>(STR("-32768")) ==               etl::to_string(INT16_MIN, str));
+      CHECK(etl::u32string<20>(STR("-2147483648")) ==          etl::to_string(INT32_MIN, str));
+      CHECK(etl::u32string<20>(STR("-9223372036854775808")) == etl::to_string(INT64_MIN, str));
     }
 
     //*************************************************************************
@@ -84,15 +84,15 @@ namespace
       CHECK(etl::u32string<120>(STR("0000128327682147483648")) ==                    etl::to_string(uint32_t(2147483648ul), str, true));
       CHECK(etl::u32string<120>(STR("00001283276821474836489223372036854775808")) == etl::to_string(uint64_t(9223372036854775808ull), str, true));
 
-      CHECK(etl::u32string<120>(STR("00001283276821474836489223372036854775808127")) ==                                   etl::to_string(int8_t(INT8_MAX), str, true));
-      CHECK(etl::u32string<120>(STR("0000128327682147483648922337203685477580812732767")) ==                              etl::to_string(int16_t(INT16_MAX), str, true));
-      CHECK(etl::u32string<120>(STR("00001283276821474836489223372036854775808127327672147483647")) ==                    etl::to_string(int32_t(INT32_MAX), str, true));
-      CHECK(etl::u32string<120>(STR("000012832768214748364892233720368547758081273276721474836479223372036854775807")) == etl::to_string(int64_t(INT64_MAX), str, true));
+      CHECK(etl::u32string<120>(STR("00001283276821474836489223372036854775808127")) ==                                   etl::to_string(INT8_MAX, str, true));
+      CHECK(etl::u32string<120>(STR("0000128327682147483648922337203685477580812732767")) ==                              etl::to_string(INT16_MAX, str, true));
+      CHECK(etl::u32string<120>(STR("00001283276821474836489223372036854775808127327672147483647")) ==                    etl::to_string(INT32_MAX, str, true));
+      CHECK(etl::u32string<120>(STR("000012832768214748364892233720368547758081273276721474836479223372036854775807")) == etl::to_string(INT64_MAX, str, true));
 
-      CHECK(etl::u32string<120>(STR("000012832768214748364892233720368547758081273276721474836479223372036854775807-128")) ==                                      etl::to_string(int8_t(INT8_MIN), str, true));
-      CHECK(etl::u32string<120>(STR("000012832768214748364892233720368547758081273276721474836479223372036854775807-128-32768")) ==                                etl::to_string(int16_t(INT16_MIN), str, true));
-      CHECK(etl::u32string<120>(STR("000012832768214748364892233720368547758081273276721474836479223372036854775807-128-32768-2147483648")) ==                     etl::to_string(int32_t(INT32_MIN), str, true));
-      CHECK(etl::u32string<120>(STR("000012832768214748364892233720368547758081273276721474836479223372036854775807-128-32768-2147483648-9223372036854775808")) == etl::to_string(int64_t(INT64_MIN), str, true));
+      CHECK(etl::u32string<120>(STR("000012832768214748364892233720368547758081273276721474836479223372036854775807-128")) ==                                      etl::to_string(INT8_MIN, str, true));
+      CHECK(etl::u32string<120>(STR("000012832768214748364892233720368547758081273276721474836479223372036854775807-128-32768")) ==                                etl::to_string(INT16_MIN, str, true));
+      CHECK(etl::u32string<120>(STR("000012832768214748364892233720368547758081273276721474836479223372036854775807-128-32768-2147483648")) ==                     etl::to_string(INT32_MIN, str, true));
+      CHECK(etl::u32string<120>(STR("000012832768214748364892233720368547758081273276721474836479223372036854775807-128-32768-2147483648-9223372036854775808")) == etl::to_string(INT64_MIN, str, true));
     }
 
     //*************************************************************************
@@ -112,15 +112,15 @@ namespace
       CHECK(etl::u32string<20>(STR("##########2147483648")) == etl::to_string(uint32_t(2147483648ul), str, format));
       CHECK(etl::u32string<20>(STR("#9223372036854775808")) == etl::to_string(uint64_t(9223372036854775808ull), str, format));
 
-      CHECK(etl::u32string<20>(STR("#################127")) == etl::to_string(int8_t(INT8_MAX), str, format));
-      CHECK(etl::u32string<20>(STR("###############32767")) == etl::to_string(int16_t(INT16_MAX), str, format));
-      CHECK(etl::u32string<20>(STR("##########2147483647")) == etl::to_string(int32_t(INT32_MAX), str, format));
-      CHECK(etl::u32string<20>(STR("#9223372036854775807")) == etl::to_string(int64_t(INT64_MAX), str, format));
+      CHECK(etl::u32string<20>(STR("#################127")) == etl::to_string(INT8_MAX, str, format));
+      CHECK(etl::u32string<20>(STR("###############32767")) == etl::to_string(INT16_MAX, str, format));
+      CHECK(etl::u32string<20>(STR("##########2147483647")) == etl::to_string(INT32_MAX, str, format));
+      CHECK(etl::u32string<20>(STR("#9223372036854775807")) == etl::to_string(INT64_MAX, str, format));
 
-      CHECK(etl::u32string<20>(STR("################-128")) == etl::to_string(int8_t(INT8_MIN), str, format));
-      CHECK(etl::u32string<20>(STR("##############-32768")) == etl::to_string(int16_t(INT16_MIN), str, format));
-      CHECK(etl::u32string<20>(STR("#########-2147483648")) == etl::to_string(int32_t(INT32_MIN), str, format));
-      CHECK(etl::u32string<20>(STR("-9223372036854775808")) == etl::to_string(int64_t(INT64_MIN), str, format));
+      CHECK(etl::u32string<20>(STR("################-128")) == etl::to_string(INT8_MIN, str, format));
+      CHECK(etl::u32string<20>(STR("##############-32768")) == etl::to_string(INT16_MIN, str, format));
+      CHECK(etl::u32string<20>(STR("#########-2147483648")) == etl::to_string(INT32_MIN, str, format));
+      CHECK(etl::u32string<20>(STR("-9223372036854775808")) == etl::to_string(INT64_MIN, str, format));
     }
 
     //*************************************************************************
@@ -140,15 +140,15 @@ namespace
       CHECK(etl::u32string<20>(STR("2147483648##########")) == etl::to_string(uint32_t(2147483648ul), str, format));
       CHECK(etl::u32string<20>(STR("9223372036854775808#")) == etl::to_string(uint64_t(9223372036854775808ull), str, format));
 
-      CHECK(etl::u32string<20>(STR("127#################")) == etl::to_string(int8_t(INT8_MAX), str, format));
-      CHECK(etl::u32string<20>(STR("32767###############")) == etl::to_string(int16_t(INT16_MAX), str, format));
-      CHECK(etl::u32string<20>(STR("2147483647##########")) == etl::to_string(int32_t(INT32_MAX), str, format));
-      CHECK(etl::u32string<20>(STR("9223372036854775807#")) == etl::to_string(int64_t(INT64_MAX), str, format));
+      CHECK(etl::u32string<20>(STR("127#################")) == etl::to_string(INT8_MAX, str, format));
+      CHECK(etl::u32string<20>(STR("32767###############")) == etl::to_string(INT16_MAX, str, format));
+      CHECK(etl::u32string<20>(STR("2147483647##########")) == etl::to_string(INT32_MAX, str, format));
+      CHECK(etl::u32string<20>(STR("9223372036854775807#")) == etl::to_string(INT64_MAX, str, format));
 
-      CHECK(etl::u32string<20>(STR("-128################")) == etl::to_string(int8_t(INT8_MIN), str, format));
-      CHECK(etl::u32string<20>(STR("-32768##############")) == etl::to_string(int16_t(INT16_MIN), str, format));
-      CHECK(etl::u32string<20>(STR("-2147483648#########")) == etl::to_string(int32_t(INT32_MIN), str, format));
-      CHECK(etl::u32string<20>(STR("-9223372036854775808")) == etl::to_string(int64_t(INT64_MIN), str, format));
+      CHECK(etl::u32string<20>(STR("-128################")) == etl::to_string(INT8_MIN, str, format));
+      CHECK(etl::u32string<20>(STR("-32768##############")) == etl::to_string(INT16_MIN, str, format));
+      CHECK(etl::u32string<20>(STR("-2147483648#########")) == etl::to_string(INT32_MIN, str, format));
+      CHECK(etl::u32string<20>(STR("-9223372036854775808")) == etl::to_string(INT64_MIN, str, format));
     }
 
     //*************************************************************************
@@ -166,15 +166,15 @@ namespace
       CHECK(etl::u32string<64>(STR("10000000000000000000000000000000")) ==                                  etl::to_string(uint32_t(2147483648ul), str, Format().base(2).width(32).fill(STR('0'))));
       CHECK(etl::u32string<64>(STR("1000000000000000000000000000000000000000000000000000000000000000")) ==  etl::to_string(uint64_t(9223372036854775808ull), str, Format().base(2).width(64).fill(STR('0'))));
 
-      CHECK(etl::u32string<64>(STR("01111111")) ==                                                          etl::to_string(int8_t(INT8_MAX), str, Format().base(2).width(8).fill(STR('0'))));
-      CHECK(etl::u32string<64>(STR("0111111111111111")) ==                                                  etl::to_string(int16_t(INT16_MAX), str, Format().base(2).width(16).fill(STR('0'))));
-      CHECK(etl::u32string<64>(STR("01111111111111111111111111111111")) ==                                  etl::to_string(int32_t(INT32_MAX), str, Format().base(2).width(32).fill(STR('0'))));
-      CHECK(etl::u32string<64>(STR("0111111111111111111111111111111111111111111111111111111111111111")) ==  etl::to_string(int64_t(INT64_MAX), str, Format().base(2).width(64).fill(STR('0'))));
+      CHECK(etl::u32string<64>(STR("01111111")) ==                                                          etl::to_string(INT8_MAX, str, Format().base(2).width(8).fill(STR('0'))));
+      CHECK(etl::u32string<64>(STR("0111111111111111")) ==                                                  etl::to_string(INT16_MAX, str, Format().base(2).width(16).fill(STR('0'))));
+      CHECK(etl::u32string<64>(STR("01111111111111111111111111111111")) ==                                  etl::to_string(INT32_MAX, str, Format().base(2).width(32).fill(STR('0'))));
+      CHECK(etl::u32string<64>(STR("0111111111111111111111111111111111111111111111111111111111111111")) ==  etl::to_string(INT64_MAX, str, Format().base(2).width(64).fill(STR('0'))));
 
-      CHECK(etl::u32string<64>(STR("10000000")) ==                                                          etl::to_string(int8_t(INT8_MIN), str, Format().base(2).width(8).fill(STR('0'))));
-      CHECK(etl::u32string<64>(STR("1000000000000000")) ==                                                  etl::to_string(int16_t(INT16_MIN), str, Format().base(2).width(16).fill(STR('0'))));
-      CHECK(etl::u32string<64>(STR("10000000000000000000000000000000")) ==                                  etl::to_string(int32_t(INT32_MIN), str, Format().base(2).width(32).fill(STR('0'))));
-      CHECK(etl::u32string<64>(STR("1000000000000000000000000000000000000000000000000000000000000000")) ==  etl::to_string(int64_t(INT64_MIN), str, Format().base(2).width(64).fill(STR('0'))));
+      CHECK(etl::u32string<64>(STR("10000000")) ==                                                          etl::to_string(INT8_MIN, str, Format().base(2).width(8).fill(STR('0'))));
+      CHECK(etl::u32string<64>(STR("1000000000000000")) ==                                                  etl::to_string(INT16_MIN, str, Format().base(2).width(16).fill(STR('0'))));
+      CHECK(etl::u32string<64>(STR("10000000000000000000000000000000")) ==                                  etl::to_string(INT32_MIN, str, Format().base(2).width(32).fill(STR('0'))));
+      CHECK(etl::u32string<64>(STR("1000000000000000000000000000000000000000000000000000000000000000")) ==  etl::to_string(INT64_MIN, str, Format().base(2).width(64).fill(STR('0'))));
     }
 
     //*************************************************************************
@@ -192,15 +192,15 @@ namespace
       CHECK(etl::u32string<22>(STR("20000000000")) ==            etl::to_string(uint32_t(2147483648ul), str, Format().base(8).width(11).fill(STR('0'))));
       CHECK(etl::u32string<22>(STR("1000000000000000000000")) == etl::to_string(uint64_t(9223372036854775808ull), str, Format().base(8).width(22).fill(STR('0'))));
 
-      CHECK(etl::u32string<22>(STR("177")) ==                    etl::to_string(int8_t(INT8_MAX),   str, Format().base(8).width(3).fill(STR('0'))));
-      CHECK(etl::u32string<22>(STR("077777")) ==                 etl::to_string(int16_t(INT16_MAX), str, Format().base(8).width(6).fill(STR('0'))));
-      CHECK(etl::u32string<22>(STR("17777777777")) ==            etl::to_string(int32_t(INT32_MAX), str, Format().base(8).width(11).fill(STR('0'))));
-      CHECK(etl::u32string<22>(STR("0777777777777777777777")) == etl::to_string(int64_t(INT64_MAX), str, Format().base(8).width(22).fill(STR('0'))));
+      CHECK(etl::u32string<22>(STR("177")) ==                    etl::to_string(INT8_MAX,   str, Format().base(8).width(3).fill(STR('0'))));
+      CHECK(etl::u32string<22>(STR("077777")) ==                 etl::to_string(INT16_MAX, str, Format().base(8).width(6).fill(STR('0'))));
+      CHECK(etl::u32string<22>(STR("17777777777")) ==            etl::to_string(INT32_MAX, str, Format().base(8).width(11).fill(STR('0'))));
+      CHECK(etl::u32string<22>(STR("0777777777777777777777")) == etl::to_string(INT64_MAX, str, Format().base(8).width(22).fill(STR('0'))));
 
-      CHECK(etl::u32string<22>(STR("200")) ==                    etl::to_string(int8_t(INT8_MIN),   str, Format().base(8).width(3).fill(STR('0'))));
-      CHECK(etl::u32string<22>(STR("100000")) ==                 etl::to_string(int16_t(INT16_MIN), str, Format().base(8).width(6).fill(STR('0'))));
-      CHECK(etl::u32string<22>(STR("20000000000")) ==            etl::to_string(int32_t(INT32_MIN), str, Format().base(8).width(11).fill(STR('0'))));
-      CHECK(etl::u32string<22>(STR("1000000000000000000000")) == etl::to_string(int64_t(INT64_MIN), str, Format().base(8).width(22).fill(STR('0'))));
+      CHECK(etl::u32string<22>(STR("200")) ==                    etl::to_string(INT8_MIN,   str, Format().base(8).width(3).fill(STR('0'))));
+      CHECK(etl::u32string<22>(STR("100000")) ==                 etl::to_string(INT16_MIN, str, Format().base(8).width(6).fill(STR('0'))));
+      CHECK(etl::u32string<22>(STR("20000000000")) ==            etl::to_string(INT32_MIN, str, Format().base(8).width(11).fill(STR('0'))));
+      CHECK(etl::u32string<22>(STR("1000000000000000000000")) == etl::to_string(INT64_MIN, str, Format().base(8).width(22).fill(STR('0'))));
     }
 
     //*************************************************************************
@@ -218,15 +218,15 @@ namespace
       CHECK(etl::u32string<16>(STR("80000000")) ==         etl::to_string(uint32_t(2147483648ul), str, Format().base(16).width(8).fill(STR('0'))));
       CHECK(etl::u32string<16>(STR("8000000000000000")) == etl::to_string(uint64_t(9223372036854775808ull), str, Format().base(16).width(16).fill(STR('0'))));
 
-      CHECK(etl::u32string<16>(STR("7f")) ==               etl::to_string(int8_t(INT8_MAX),   str, Format().base(16).width(2).fill(STR('0'))));
-      CHECK(etl::u32string<16>(STR("7fff")) ==             etl::to_string(int16_t(INT16_MAX), str, Format().base(16).width(4).fill(STR('0'))));
-      CHECK(etl::u32string<16>(STR("7fffffff")) ==         etl::to_string(int32_t(INT32_MAX), str, Format().base(16).width(8).fill(STR('0'))));
-      CHECK(etl::u32string<16>(STR("7fffffffffffffff")) == etl::to_string(int64_t(INT64_MAX), str, Format().base(16).width(16).fill(STR('0'))));
+      CHECK(etl::u32string<16>(STR("7f")) ==               etl::to_string(INT8_MAX,   str, Format().base(16).width(2).fill(STR('0'))));
+      CHECK(etl::u32string<16>(STR("7fff")) ==             etl::to_string(INT16_MAX, str, Format().base(16).width(4).fill(STR('0'))));
+      CHECK(etl::u32string<16>(STR("7fffffff")) ==         etl::to_string(INT32_MAX, str, Format().base(16).width(8).fill(STR('0'))));
+      CHECK(etl::u32string<16>(STR("7fffffffffffffff")) == etl::to_string(INT64_MAX, str, Format().base(16).width(16).fill(STR('0'))));
 
-      CHECK(etl::u32string<16>(STR("80")) ==               etl::to_string(int8_t(INT8_MIN),   str, Format().base(16).width(2).fill(STR('0'))));
-      CHECK(etl::u32string<16>(STR("8000")) ==             etl::to_string(int16_t(INT16_MIN), str, Format().base(16).width(4).fill(STR('0'))));
-      CHECK(etl::u32string<16>(STR("80000000")) ==         etl::to_string(int32_t(INT32_MIN), str, Format().base(16).width(8).fill(STR('0'))));
-      CHECK(etl::u32string<16>(STR("8000000000000000")) == etl::to_string(int64_t(INT64_MIN), str, Format().base(16).width(16).fill(STR('0'))));
+      CHECK(etl::u32string<16>(STR("80")) ==               etl::to_string(INT8_MIN,   str, Format().base(16).width(2).fill(STR('0'))));
+      CHECK(etl::u32string<16>(STR("8000")) ==             etl::to_string(INT16_MIN, str, Format().base(16).width(4).fill(STR('0'))));
+      CHECK(etl::u32string<16>(STR("80000000")) ==         etl::to_string(INT32_MIN, str, Format().base(16).width(8).fill(STR('0'))));
+      CHECK(etl::u32string<16>(STR("8000000000000000")) == etl::to_string(INT64_MIN, str, Format().base(16).width(16).fill(STR('0'))));
     }
 
 
