@@ -360,6 +360,7 @@ namespace
     {
       Data data(initial_data.begin(), initial_data.end());
       Data other_data;
+      other_data.push_back(nullptr);
 
       other_data = std::move(data);
 
@@ -1068,6 +1069,52 @@ namespace
       CHECK_EQUAL(&d2, data.emplace_back(&d2));
     }
 
+    //*************************************************************************
+    TEST(test_emplace_default)
+    {
+      static int initial = 0;
+
+      // First fill with Initial values.
+      etl::vector<int*, SIZE> data;
+      data.resize(SIZE, &initial);
+      data.clear();
+
+      // Then emplace Default values.
+      for (size_t i = 0; i < SIZE; ++i)
+      {
+        data.emplace(data.begin());
+      }
+
+      // Compare with an array of default values.
+      std::array<int*, SIZE> compare_data;
+      compare_data.fill(nullptr);
+
+      CHECK_TRUE(std::equal(compare_data.begin(), compare_data.end(), data.begin()));
+    }
+
+    //*************************************************************************
+    TEST(test_emplace_back_default)
+    {
+      static int initial = 0;
+
+      // First fill with initial values.
+      etl::vector<int*, SIZE> data;
+      data.resize(SIZE, &initial);
+      data.clear();
+
+      // Then emplace default values.
+      for (size_t i = 0; i < SIZE; ++i)
+      {
+        data.emplace_back();
+      }
+
+      // Compare with an array of default values.
+      std::array<int*, SIZE> compare_data;
+      compare_data.fill(nullptr);
+
+      CHECK_TRUE(std::equal(compare_data.begin(), compare_data.end(), data.begin()));
+    }
+
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_pop_back)
     {
